@@ -4,6 +4,11 @@
  * Usage:	ascii-xfr -s|-r [-ednv] [-c character delay] [-l line delay]
  *
  * 08.03.98 added a patch from Bo Branten <bosse@ing.umu.se>
+ *
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -11,7 +16,7 @@
 #endif
 
 #include "rcsid.h"
-RCSID("$Id: ascii-xfr.c,v 1.6 2005/08/04 20:33:33 al-guest Exp $")
+RCSID("$Id: ascii-xfr.c,v 1.7 2007-10-10 20:18:20 al-guest Exp $")
 
 #include <errno.h>
 #include <stdio.h>
