@@ -17,6 +17,11 @@
  *		moved from config.c to a separate file, so they are easier
  *		to use in both the Minicom main program and runscript.
  *
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ *
  * 27.10.98 jl  converted do_log to use stdarg
  */
 #ifdef HAVE_CONFIG_H
@@ -24,7 +29,7 @@
 #endif
 
 #include "rcsid.h"
-RCSID("$Id: common.c,v 1.7 2005/10/31 12:13:51 al-guest Exp $")
+RCSID("$Id: common.c,v 1.8 2007-10-10 20:18:20 al-guest Exp $")
 
 #include "port.h"
 #include "minicom.h"
