@@ -10,6 +10,10 @@
  *		as published by the Free Software Foundation; either version
  *		2 of the License, or (at your option) any later version.
  *
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
  *   jl 22.06.97  Logging connects and disconnects.
  *   jl 23.06.97  Adjustable DTR droptime
  *   jl 21.09.97  Conversion table filenames in dialdir
@@ -26,8 +30,11 @@
 #include <config.h>
 #endif
 
+#include <stdint.h>
+#include <arpa/inet.h>
+
 #include "rcsid.h"
-RCSID("$Id: dial.c,v 1.21 2005/10/31 12:13:51 al-guest Exp $")
+RCSID("$Id: dial.c,v 1.26 2007-10-10 20:18:20 al-guest Exp $")
 
 #include "port.h"
 #include "minicom.h"
@@ -75,7 +82,7 @@ struct v3_dialent {
   struct dialent *next;
 };
 
-struct dialent {
+struct v4_dialent {
   char name[32];
   char number[32];
   char script[32];
@@ -91,10 +98,33 @@ struct dialent {
   char lasttime[9];	/* jl 22.06.97 */
   int  count;		/* jl 22.06.97 */
   char convfile[16];	/* jl 21.09.97 */
-  char stopb[2]; 	/* jl 10.02.2000 */
+  char stopb[2];	/* jl 10.02.2000 */
   struct dialent *next;
 };
 
+/* v5 is a packed version of v4 so that there's no difference between 32 and
+ * 64 bit versions as well as LE and BE.
+ */
+struct dialent {
+  char     name[32];
+  char     number[32];
+  char     script[32];
+  char     username[32];
+  char     password[32];
+  char     term;
+  char     baud[8];
+  char     parity[2];
+  char     dialtype;
+  char     flags;
+  char     bits[2];
+  char     lastdate[9];
+  char     lasttime[9];
+  uint32_t count;
+  char     convfile[16];
+  char     stopb[2];
+  struct dialent *next;
+} __attribute__((packed));
+
 /* Version info. */
 #define DIALMAGIC 0x55AA
 struct dver {
@@ -105,7 +135,7 @@ struct dver {
   short res2;
   short res3;
   short res4;
-};
+} __attribute__((packed));
 
 /* Forward declaration */
 static void writedialdir(void);
@@ -129,11 +159,8 @@ char *dial_pass;
  */
 const char* change_baud(const char *s)
 {
-  int max = m_getmaxspd();
-
   while (s && *s
-         && update_bbp_from_char(*s, P_BAUDRATE, P_BITS, P_PARITY,
-	                         P_STOPB, 0, max))
+         && update_bbp_from_char(*s, P_BAUDRATE, P_BITS, P_PARITY, P_STOPB, 0))
     ++s;
 
   // reinitialise the port and update the status line
@@ -176,7 +203,7 @@ void mputs(const char *s, int how)
           c = *s;
           break;
         case 'U':
-          if (dial_user && *dial_user) 
+          if (dial_user && *dial_user)
             mputs (dial_user, how);
           s++;
           continue;
@@ -223,7 +250,7 @@ void modeminit(void)
   w = mc_tell(_("Initializing Modem"));
   m_dtrtoggle(portfd, 1);         /* jl 23.06.97 */
   mputs(P_MINIT, 0);
-  wclose(w, 1);
+  mc_wclose(w, 1);
 }
 
 /*
@@ -239,7 +266,7 @@ void modemreset(void)
   w = mc_tell(_("Resetting Modem"));
   mputs(P_MRESET, 0);
   sleep(1);
-  wclose(w, 1);
+  mc_wclose(w, 1);
 }
 
 /*
@@ -274,7 +301,7 @@ void hangup(void)
 #endif
   /* If we don't have DCD support fake DCD dropped */
   bogus_dcd = 0;
-  wclose(w, 1);
+  mc_wclose(w, 1);
   if (st)
     time_status();
 }
@@ -288,12 +315,12 @@ void sendbreak()
   WIN *w;
 
   w = mc_tell(_("Sending BREAK"));
-  wcursor(w, CNONE);
+  mc_wcursor(w, CNONE);
 
   m_break(portfd);
-  wclose(w, 1);
+  mc_wclose(w, 1);
 }
-  
+
 WIN *dialwin;
 int dialtime;
 
@@ -352,16 +379,16 @@ static int dialfailed(char *s, int rtime)
   int f, x;
   int ret = 0;
 
-  wlocate(dialwin, 1, 5);
-  wprintf(dialwin, _("    No connection: %s.      \n"), s);
+  mc_wlocate(dialwin, 1, 5);
+  mc_wprintf(dialwin, _("    No connection: %s.      \n"), s);
   if (rtime < 0) {
-    wprintf(dialwin, _("   Press any key to continue..    "));
-    if (check_io(-1, 0, 10000, NULL, NULL) & 2) 
+    mc_wprintf(dialwin, _("   Press any key to continue..    "));
+    if (check_io(-1, 0, 10000, NULL, NULL) & 2)
       keyboard(KGETKEY, 0);
     return 0;
   }
-  wprintf(dialwin, _("     Retry in %2d seconds             "), rtime);
-  
+  mc_wprintf(dialwin, _("     Retry in %2d seconds             "), rtime);
+
   for (f = rtime - 1; f >= 0; f--) {
     x = check_io(-1, 0, 1000, NULL, NULL);
     if (x & 2) {
@@ -371,8 +398,8 @@ static int dialfailed(char *s, int rtime)
         ret = -1;
       break;
     }
-    wlocate(dialwin, 0, 6);
-    wprintf(dialwin, _("     Retry in %2d seconds             "), f);
+    mc_wlocate(dialwin, 0, 6);
+    mc_wprintf(dialwin, _("     Retry in %2d seconds             "), f);
   }
 #ifdef HAVE_USLEEP
   /* MARK updated 02/17/94 - Min dial delay set to 0.35 sec instead of 1 sec */
@@ -382,9 +409,9 @@ static int dialfailed(char *s, int rtime)
   if (f < 0)
     sleep(1);
 #endif
-  wlocate(dialwin, 1, 5);
-  wprintf(dialwin, "                                       \n");
-  wprintf(dialwin, "                                             ");
+  mc_wlocate(dialwin, 1, 5);
+  mc_wprintf(dialwin, "                                       \n");
+  mc_wprintf(dialwin, "                                             ");
   return ret;
 }
 
@@ -412,18 +439,18 @@ long dial(struct dialent *d, struct dialent **d2)
     return(retst);
   }
 
-  dialwin = wopen(18, 9, 62, 16, BSINGLE, stdattr, mfcolor, mbcolor, 0, 0, 1);
-  wtitle(dialwin, TMID, _("Autodial"));
-  wcursor(dialwin, CNONE);
+  dialwin = mc_wopen(18, 9, 62, 16, BSINGLE, stdattr, mfcolor, mbcolor, 0, 0, 1);
+  mc_wtitle(dialwin, TMID, _("Autodial"));
+  mc_wcursor(dialwin, CNONE);
 
-  wputs(dialwin, "\n");
-  wprintf(dialwin, " %s : %s\n", _("Dialing"), d->name);
-  wprintf(dialwin, _("      At : %s"), d->number);
-  wprintf(dialwin, "\n"); /* help translators */
+  mc_wputs(dialwin, "\n");
+  mc_wprintf(dialwin, " %s : %s\n", _("Dialing"), d->name);
+  mc_wprintf(dialwin, _("      At : %s"), d->number);
+  mc_wprintf(dialwin, "\n"); /* help translators */
   if (d->lastdate[0] && d->lasttime[0])		/* jl 26.01.98 */
-    wprintf(dialwin, _(" Last on : %s at %s"), d->lastdate, d->lasttime);
-  wprintf(dialwin, "\n");
-  wredraw(dialwin, 1);
+    mc_wprintf(dialwin, _(" Last on : %s at %s"), d->lastdate, d->lasttime);
+  mc_wprintf(dialwin, "\n");
+  mc_wredraw(dialwin, 1);
 
   /* Tell keyboard routines we need them. */
   keyboard(KSIGIO, 0);
@@ -446,17 +473,17 @@ MainLoop:
         if (d == (struct dialent *)NULL)
           d = dialents;
       } while (!(d->flags & FL_TAG));
-      wlocate(dialwin, 0, 1);
-      wprintf(dialwin, " %s : %s", _("Dialing"), d->name);
-      wclreol(dialwin);
-      wprintf(dialwin, "\n"); /* helps translators */
-      wprintf(dialwin, _("      At : %s"), d->number);
-      wclreol(dialwin);
+      mc_wlocate(dialwin, 0, 1);
+      mc_wprintf(dialwin, " %s : %s", _("Dialing"), d->name);
+      mc_wclreol(dialwin);
+      mc_wprintf(dialwin, "\n"); /* helps translators */
+      mc_wprintf(dialwin, _("      At : %s"), d->number);
+      mc_wclreol(dialwin);
       if (d->lastdate[0] && d->lasttime[0]) {
-	wprintf(dialwin, "\n"); /* don't merge with next printf, helps translators */
-        wprintf(dialwin, _(" Last on : %s at %s"),
+	mc_wprintf(dialwin, "\n"); /* don't merge with next printf, helps translators */
+        mc_wprintf(dialwin, _(" Last on : %s at %s"),
                 d->lastdate, d->lasttime);
-        wclreol(dialwin);
+        mc_wclreol(dialwin);
       }
     }
 
@@ -468,11 +495,11 @@ MainLoop:
     last = now;
 
     /* Show used time */
-    wlocate(dialwin, 0, 4);
-    wprintf(dialwin, _("    Time : %-3d"), dialtime);
+    mc_wlocate(dialwin, 0, 4);
+    mc_wprintf(dialwin, _("    Time : %-3d"), dialtime);
     if (maxretries > 1)
-      wprintf(dialwin, _("     Attempt #%d"), retries);
-    wputs(dialwin, _("\n\n\n Escape to cancel, space to retry."));
+      mc_wprintf(dialwin, _("     Attempt #%d"), retries);
+    mc_wputs(dialwin, _("\n\n\n Escape to cancel, space to retry."));
 
     /* Start the dial */
     m_flush(portfd);
@@ -518,7 +545,7 @@ MainLoop:
           break;
         }
         keyboard(KSTOP, 0);
-        wclose(dialwin, 1);
+        mc_wclose(dialwin, 1);
         return retst;
       }
       if (x & 1) {
@@ -566,9 +593,9 @@ MainLoop:
             strcpy(P_CONVF, d->convfile);
           }
 
-          wlocate(dialwin, 1, 7);
+          mc_wlocate(dialwin, 1, 7);
           if (d->script[0] == 0) {
-            wputs(dialwin,
+            mc_wputs(dialwin,
                   _("Connected. Press any key to continue"));
 #ifdef VC_MUSIC
             if (P_SOUND[0] == 'Y')
@@ -581,17 +608,17 @@ MainLoop:
 #else
             /* MARK updated 02/17/94 - If VC_MUSIC is not */
             /* defined, then at least make some beeps! */
-            if (P_SOUND[0] == 'Y') 
-              wputs(dialwin,"\007\007\007");
+            if (P_SOUND[0] == 'Y')
+              mc_wputs(dialwin,"\007\007\007");
 #endif
             x = check_io(-1, 0, 0, NULL, NULL);
             if ((x & 2) == 2)
               keyboard(KGETKEY, 0);
           }
           keyboard(KSTOP, 0);
-          wclose(dialwin, 1);
+          mc_wclose(dialwin, 1);
           /* Print out the connect strings. */
-          wprintf(us, "\r\n%s\r\n", modbuf);
+          mc_wprintf(us, "\r\n%s\r\n", modbuf);
           dialwin = NULL;
 
           /* Un-tag this entry. */
@@ -601,7 +628,7 @@ MainLoop:
           if (d2 != (struct dialent**)NULL)
             *d2 = d;	/* jl 23.09.97 */
 
-          /* Here should placed code to untag phones with similar names */ 
+          /* Here should placed code to untag phones with similar names */
           if (P_MULTILINE[0] == 'Y') {
             struct dialent *d3 = dialents;
 
@@ -609,7 +636,7 @@ MainLoop:
               if (!strcmp(d3->name, d->name))
                 d3->flags &= ~FL_TAG;
               d3 = d3->next;
-            }				
+            }
           }				/*  er 27-Apr-99 */
           return retst;
         }
@@ -628,7 +655,7 @@ MainLoop:
               x = dialfailed(t, rdelay);
               if (x < 0) {
                 keyboard(KSTOP, 0);
-                wclose(dialwin, 1);
+                mc_wclose(dialwin, 1);
                 return retst;
               }
             }
@@ -645,8 +672,8 @@ MainLoop:
         dialtime -= (now - last);
         if (dialtime < 0)
           dialtime = 0;
-        wlocate(dialwin, 11, 4);
-        wprintf(dialwin, "%-3d  ", dialtime);
+        mc_wlocate(dialwin, 11, 4);
+        mc_wprintf(dialwin, "%-3d  ", dialtime);
         if (dialtime <= 0) {
           mputs(P_MDIALCAN, 0);
           reason = _("Timeout");
@@ -655,7 +682,7 @@ MainLoop:
             x = dialfailed(reason, rdelay);
             if (x < 0) {
               keyboard(KSTOP, 0);
-              wclose(dialwin, 1);
+              mc_wclose(dialwin, 1);
               return retst;
             }
           }
@@ -663,10 +690,10 @@ MainLoop:
       }
       last = now;
     }
-  } /* End of main while cq MainLoop */	
+  } /* End of main while cq MainLoop */
   dialfailed(reason, -1);
   keyboard(KSTOP, 0);
-  wclose(dialwin, 1);
+  mc_wclose(dialwin, 1);
   return retst;
 }
 
@@ -675,9 +702,9 @@ MainLoop:
  */
 static struct dialent *mkstdent(void)
 {
-  struct dialent *d = (struct dialent *)malloc(sizeof (struct dialent));
-  
-  if (d == (struct dialent *)0)
+  struct dialent *d = malloc(sizeof(struct dialent));
+
+  if (d == NULL)
     return d;
 
   d->name[0] = 0;
@@ -696,15 +723,37 @@ static struct dialent *mkstdent(void)
   d->count = 0;
   d->convfile[0] = 0;	/* jl 21.09.97 */
   strcpy(d->stopb, "1");
-  d->next = (struct dialent *)0;
+  d->next = NULL;
 
   return d;
 }
 
+static void convert_to_save_order(struct dialent *dst, const struct dialent *src)
+{
+  memcpy(dst, src, sizeof(*dst));
+  dst->count = htonl(dst->count);
+}
+
+static void convert_to_host_order(struct dialent *dst, const struct dialent *src)
+{
+  memcpy(dst, src, sizeof(*dst));
+  dst->count = ntohl(dst->count);
+}
+
+/* Read version 5 of the dialing directory. */
+void v5_read(FILE *fp, struct dialent *d)
+{
+  struct dialent dent_n;
+  fread(&dent_n, sizeof(dent_n), 1, fp);
+  convert_to_host_order(d, &dent_n);
+}
+
 /* Read version 4 of the dialing directory. */
 void v4_read(FILE *fp, struct dialent *d, struct dver *dv)
 {
-  (void) fread((char *)d, dv->size, (size_t)1, fp);
+  struct v4_dialent v4;
+
+  fread(&v4, dv->size, 1, fp);
 
   if (dv->size < sizeof(struct dialent)) {
     if (dv->size < offsetof(struct dialent, count) + sizeof(struct dialent *)) {
@@ -713,7 +762,7 @@ void v4_read(FILE *fp, struct dialent *d, struct dver *dv)
       d->lastdate[0] = 0;
     }
     if (dv->size < offsetof(struct dialent, stopb) + sizeof(struct dialent *))
-      d->convfile[0]=0;
+      d->convfile[0] = 0;
     strcpy(d->stopb, "1");
   }
 }
@@ -723,7 +772,7 @@ void v3_read(FILE *fp, struct dialent *d)
 {
   struct v3_dialent v3;   /* jl 22.06.97 */
 
-  (void) fread((char *)&v3, sizeof(v3), (size_t)1, fp);
+  fread(&v3, sizeof(v3), 1, fp);
   memcpy(d, &v3, offsetof(struct v3_dialent, next));
 
   d->lastdate[0] = 0;
@@ -738,7 +787,7 @@ void v2_read(FILE *fp, struct dialent *d)
 {
   struct v3_dialent v3;   /* jl 22.06.97 */
 
-  fread((char *)&v3, sizeof(v3), (size_t)1, fp);
+  fread((char *)&v3, sizeof(v3), 1, fp);
   memcpy(d, &v3, offsetof(struct v3_dialent, next));
   if (d->flags & FL_ANSI)
     d->flags |= FL_WRAP;
@@ -785,15 +834,17 @@ int readdialdir(void)
   char copycmd[512];
   static int didread = 0;
   int f;
-  struct dialent *d = NULL, *prev = (struct dialent *)0;
+  struct dialent *d = NULL, *tail = NULL;
   struct dver dial_ver;
   WIN *w;
 
   if (didread)
-    return(0);
+    return 0;
   didread = 1;
   nrents = 1;
-  tagged = (char *)malloc(1);
+  tagged = malloc(1);
+  if (!tagged)
+    return 0;
   tagged[0] = 0;
 
   /* Make the manual dial entry. */
@@ -804,7 +855,7 @@ int readdialdir(void)
   snprintf(dfile, sizeof(dfile), "%s/.dialdir", homedir);
 
   /* Try to open ~/.dialdir */
-  if ((fp = sfopen(dfile, "r")) == (FILE *)NULL) {
+  if ((fp = sfopen(dfile, "r")) == NULL) {
     if (errno == EPERM) {
       werror(_("Cannot open ~/.dialdir: permission denied"));
       dialents = mkstdent();
@@ -831,8 +882,10 @@ int readdialdir(void)
     /* First version without version info. */
     dial_ver.version = 0;
     fseek(fp, 0L, SEEK_SET);
-  } else
+  } else {
+    dial_ver.size = ntohs(dial_ver.size);
     size -= sizeof(dial_ver);
+  }
 
   /* See if the size of the file is allright. */
   switch (dial_ver.version) {
@@ -851,17 +904,22 @@ int readdialdir(void)
        * if you just add fields to the end of the dialent structure
        * before the *next pointer and don't change existing fields.
        * Just update the initialization in the functions
-       * v4_read and mkstdent (and whatever you added the field for)
+       * v4_read/v5_read and mkstdent (and whatever you added the field for)
        * jl 21.09.97
        */
       if (dial_ver.size < 200 ||
-          dial_ver.size > sizeof(struct dialent)) {
+          dial_ver.size > sizeof(struct v4_dialent)) {
         werror(_("Phonelist garbled (unknown version?)"));
-        dendd = 1;
         dialents = mkstdent();
         return -1;
       }
       break;
+    case 5:
+      if (dial_ver.size != sizeof(struct dialent)) {
+	werror(_("Phonelist corrupted"));
+	return -1;
+      }
+      break;
     default:
       werror(_("Unknown dialing directory version"));
       dendd = 1;
@@ -886,12 +944,11 @@ int readdialdir(void)
     return 0;
   }
   for(f = 1; f <= nrents; f++) {
-    if ((d = (struct dialent *)malloc(sizeof (struct dialent))) ==
-        (struct dialent *)0) {
+    if ((d = malloc(sizeof (struct dialent))) == NULL) {
       if (f == 1)
         dialents = mkstdent();
       else
-        prev->next = (struct dialent *)0;
+        tail->next = NULL;
 
       werror(_("Out of memory while reading dialing directory"));
       fclose(fp);
@@ -913,18 +970,21 @@ int readdialdir(void)
       case 4:
         v4_read(fp, d, &dial_ver);
         break;
+      case 5:
+	v5_read(fp, d);
+	break;
     }
     /* MINIX terminal type is obsolete */
     if (d->term == 2)
       d->term = 1;
 
-    if (prev != (struct dialent *)0)
-      prev->next = d;
+    if (tail)
+      tail->next = d;
     else
       dialents = d;
-    prev = d;
+    tail = d;
   }
-  d->next = (struct dialent *)0;
+  d->next = NULL;
   fclose(fp);
   if (dial_ver.size < sizeof(struct dialent)) {
     if (snprintf(copycmd,sizeof(copycmd),
@@ -937,7 +997,7 @@ int readdialdir(void)
         w = mc_tell("%s", copycmd);
         if (w) {
           sleep(2);
-          wclose(w,1);
+          mc_wclose(w,1);
         }
         writedialdir();
       }
@@ -965,7 +1025,7 @@ static void writedialdir(void)
   snprintf(dfile, sizeof(dfile), "%s/.dialdir", homedir);
 
   omask = umask(077);
-  if ((fp = sfopen(dfile, "w")) == (FILE *)0) {
+  if ((fp = sfopen(dfile, "w")) == NULL) {
     umask(omask);
     werror(_("Cannot open ~/.dialdir for writing!"));
     dendd = 1;
@@ -976,13 +1036,13 @@ static void writedialdir(void)
   d = dialents;
   /* Set up version info. */
   dial_ver.magic = DIALMAGIC;
-  dial_ver.version = 4;
-  dial_ver.size = sizeof(struct dialent);
+  dial_ver.version = 5;
+  dial_ver.size = htons(sizeof(struct dialent));
   dial_ver.res1 = 0;	/* We don't use these res? fields, but let's */
   dial_ver.res2 = 0;	/* initialize them to a known init value for */
   dial_ver.res3 = 0;	/* whoever needs them later / jl 22.09.97    */
   dial_ver.res4 = 0;
-  if (fwrite(&dial_ver, sizeof(dial_ver), (size_t)1, fp) != 1) {
+  if (fwrite(&dial_ver, sizeof(dial_ver), 1, fp) != 1) {
     werror(_("Error writing to ~/.dialdir!"));
     fclose(fp);
     return;
@@ -990,9 +1050,11 @@ static void writedialdir(void)
 
   /* Write dialing directory */
   while (d) {
+    struct dialent dent_n;
     oldfl = d->flags;
     d->flags &= FL_SAVE;
-    if (fwrite(d, sizeof(struct dialent), (size_t)1, fp) != 1) {
+    convert_to_save_order(&dent_n, d);
+    if (fwrite(&dent_n, sizeof(dent_n), 1, fp) != 1) {
       werror(_("Error writing to ~/.dialdir!"));
       fclose(fp);
       return;
@@ -1047,8 +1109,8 @@ static void dedit_toggle_entry(WIN *w, int x, int y, int toggle,
     buf[i] = ' ';
   buf[l - 1] = 0;
 
-  wlocate(w, x, y);
-  wputs(w, buf);
+  mc_wlocate(w, x, y);
+  mc_wputs(w, buf);
 }
 
 /*
@@ -1072,30 +1134,30 @@ static void dedit(struct dialent *d)
        *conversion_table    = _(" L -  Conversion table    :"),
        *question            = _("Change which setting?");
   
-  w = wopen(5, 4, 75, 19, BDOUBLE, stdattr, mfcolor, mbcolor, 0, 0, 1);
-  wprintf(w, "%s %s\n", name, d->name);
-  wprintf(w, "%s %s\n", number, d->number);
-  wprintf(w, "%s %d\n", dial_string, d->dialtype + 1);
-  wprintf(w, "%s %s\n", local_echo, _(yesno(d->flags & FL_ECHO)));
-  wprintf(w, "%s %s\n", script, d->script);
-  wprintf(w, "%s %s\n", username, d->username);
-  wprintf(w, "%s %s\n", password, d->password);
-  wprintf(w, "%s %s\n", terminal_emulation, te[d->term - 1]);
-  wprintf(w, "%s %s\n", backspace_key_sends,
+  w = mc_wopen(5, 4, 75, 19, BDOUBLE, stdattr, mfcolor, mbcolor, 0, 0, 1);
+  mc_wprintf(w, "%s %s\n", name, d->name);
+  mc_wprintf(w, "%s %s\n", number, d->number);
+  mc_wprintf(w, "%s %d\n", dial_string, d->dialtype + 1);
+  mc_wprintf(w, "%s %s\n", local_echo, _(yesno(d->flags & FL_ECHO)));
+  mc_wprintf(w, "%s %s\n", script, d->script);
+  mc_wprintf(w, "%s %s\n", username, d->username);
+  mc_wprintf(w, "%s %s\n", password, d->password);
+  mc_wprintf(w, "%s %s\n", terminal_emulation, te[d->term - 1]);
+  mc_wprintf(w, "%s %s\n", backspace_key_sends,
           d->flags & FL_DEL ? _("Delete") : _("Backspace"));
-  wprintf(w, "%s %s\n", linewrap,
+  mc_wprintf(w, "%s %s\n", linewrap,
           d->flags & FL_WRAP ? _("On") : _("Off"));
-  wprintf(w, "%s %s %s%s%s\n", line_settings,
+  mc_wprintf(w, "%s %s %s%s%s\n", line_settings,
           d->baud, d->bits, d->parity, d->stopb);
-  wprintf(w, "%s %s\n", conversion_table, d->convfile);
-  wprintf(w, _("      Last dialed         : %s %s\n"),d->lastdate,d->lasttime);
-  wprintf(w, _("      Times on            : %d"),d->count);
-  wlocate(w, 4, 15);
-  wputs(w, question);
-  wredraw(w, 1);
+  mc_wprintf(w, "%s %s\n", conversion_table, d->convfile);
+  mc_wprintf(w, _("      Last dialed         : %s %s\n"),d->lastdate,d->lasttime);
+  mc_wprintf(w, _("      Times on            : %d"),d->count);
+  mc_wlocate(w, 4, 15);
+  mc_wputs(w, question);
+  mc_wredraw(w, 1);
 
   while (1) {
-    wlocate(w, mbslen (question) + 5, 15);
+    mc_wlocate(w, mbslen (question) + 5, 15);
     c = wxgetch();
     if (c >= 'a')
       c -= 32;
@@ -1103,47 +1165,47 @@ static void dedit(struct dialent *d)
       case '\033':
       case '\r':
       case '\n':
-        wclose(w, 1);
+        mc_wclose(w, 1);
         return;
       case 'A':
-        wlocate(w, mbslen (name) + 1, 0);
-        wgets(w, d->name, 31, 32);
+        mc_wlocate(w, mbslen (name) + 1, 0);
+        mc_wgets(w, d->name, 31, 32);
         break;
       case 'B':
-        wlocate(w, mbslen (number) + 1, 1);
-        wgets(w, d->number, 31, 32);
+        mc_wlocate(w, mbslen (number) + 1, 1);
+        mc_wgets(w, d->number, 31, 32);
         break;
       case 'C':
         d->dialtype = (d->dialtype + 1) % 3;
-        wlocate(w, mbslen (dial_string) + 1, 2);
-        wprintf(w, "%d", d->dialtype + 1);
-        wflush();
+        mc_wlocate(w, mbslen (dial_string) + 1, 2);
+        mc_wprintf(w, "%d", d->dialtype + 1);
+        mc_wflush();
         break;
       case 'D':
         d->flags ^= FL_ECHO;
-        wlocate(w, mbslen (local_echo) + 1, 3);
-        wprintf(w, "%s", _(yesno(d->flags & FL_ECHO)));
-        wflush();
+        mc_wlocate(w, mbslen (local_echo) + 1, 3);
+        mc_wprintf(w, "%s", _(yesno(d->flags & FL_ECHO)));
+        mc_wflush();
         break;
       case 'E':
-        wlocate(w, mbslen (script) + 1, 4);
-        wgets(w, d->script, 31, 32);
+        mc_wlocate(w, mbslen (script) + 1, 4);
+        mc_wgets(w, d->script, 31, 32);
         break;
       case 'F':
-        wlocate(w, mbslen (username) + 1, 5);
-        wgets(w, d->username, 31, 32);
+        mc_wlocate(w, mbslen (username) + 1, 5);
+        mc_wgets(w, d->username, 31, 32);
         break;
       case 'G':
-        wlocate(w, mbslen (password) + 1, 6);
-        wgets(w, d->password, 31, 32);
+        mc_wlocate(w, mbslen (password) + 1, 6);
+        mc_wgets(w, d->password, 31, 32);
         break;
       case 'H':
         d->term = (d->term % 3) + 1;
         /* MINIX == 2 is obsolete. */
         if (d->term == 2)
           d->term = 3;
-        wlocate(w, mbslen (terminal_emulation) + 1, 7);
-        wputs(w, te[d->term - 1]);
+        mc_wlocate(w, mbslen (terminal_emulation) + 1, 7);
+        mc_wputs(w, te[d->term - 1]);
 
         /* Also set backspace key. */
         if (d->term == ANSI) {
@@ -1170,13 +1232,13 @@ static void dedit(struct dialent *d)
         break;
       case 'K':
         get_bbp(d->baud, d->bits, d->parity, d->stopb, 1);
-        wlocate(w, mbslen (line_settings) + 1, 10);
-        wprintf(w, "%s %s%s%s  ",
+        mc_wlocate(w, mbslen (line_settings) + 1, 10);
+        mc_wprintf(w, "%s %s%s%s  ",
                 d->baud, d->bits, d->parity, d->stopb);
         break;
       case 'L':	/* jl 21.09.97 */
-        wlocate(w, mbslen (conversion_table) + 1, 11);
-        wgets(w, d->convfile, 15, 16);
+        mc_wlocate(w, mbslen (conversion_table) + 1, 11);
+        mc_wgets(w, d->convfile, 15, 16);
         break;
       default:
         break;
@@ -1207,9 +1269,9 @@ static void horiz_draw(size_t k)
 {
   static const char spaces[] = "        ";
 
-  wprintf(dsub, "%.*s", what_padding[k][0], spaces);
-  wprintf(dsub, "%.*s", what_lens[k], _(what[k]));
-  wprintf(dsub, "%.*s", what_padding[k][1], spaces);
+  mc_wprintf(dsub, "%.*s", what_padding[k][0], spaces);
+  mc_wprintf(dsub, "%.*s", what_lens[k], _(what[k]));
+  mc_wprintf(dsub, "%.*s", what_padding[k][1], spaces);
 }
 
 /*
@@ -1221,20 +1283,20 @@ static void dhili(int position_dialing_directory, int k)
     return;
 
   if (dprev >= 0) {
-    wlocate(dsub, position_dialing_directory + DIAL_WIDTH * dprev, 0);
+    mc_wlocate(dsub, position_dialing_directory + DIAL_WIDTH * dprev, 0);
     if (!useattr) {
-      wputs(dsub, " ");
+      mc_wputs(dsub, " ");
     } else {
-      wsetattr(dsub, XA_REVERSE | stdattr);
+      mc_wsetattr(dsub, XA_REVERSE | stdattr);
       horiz_draw(dprev);
     }
   }
   dprev = k;
-  wlocate(dsub, position_dialing_directory + DIAL_WIDTH * k, 0);
+  mc_wlocate(dsub, position_dialing_directory + DIAL_WIDTH * k, 0);
   if (!useattr) {
-    wputs(dsub, ">");
+    mc_wputs(dsub, ">");
   } else {
-    wsetattr(dsub, stdattr);
+    mc_wsetattr(dsub, stdattr);
     horiz_draw(k);
   }
 }
@@ -1251,17 +1313,17 @@ static void prdir(WIN *dialw, int top, int cur)
 
   start = cur - top;
   dirflush = 0;
-  wlocate(dialw, 0, start + 1);
+  mc_wlocate(dialw, 0, start + 1);
   for (f = start; f < dialw->ys - 2; f++) {
     d = getno(f + top);
     if (d == (struct dialent *)0)
       break;
-    wprintf(dialw, fmt, f+1+top, (d->flags & FL_TAG) ? '>' : ' ',
+    mc_wprintf(dialw, fmt, f+1+top, (d->flags & FL_TAG) ? '>' : ' ',
             d->name, d->number, d->lastdate, d->lasttime, 
             d->count, d->script);
   }
   dirflush = 1;
-  wflush();
+  mc_wflush();
 }
 
 /*
@@ -1322,13 +1384,13 @@ int move_entry(WIN *dialw, struct dialent *d, int cur, int *top)
     /* If the list order changed, redraw the directory window */
     if (cur != ocur) {
       /* First remove cursor bar from the old position */
-      wcurbar(dialw, ocur + 1 - *top, XA_NORMAL | stdattr);
+      mc_wcurbar(dialw, ocur + 1 - *top, XA_NORMAL | stdattr);
       if (cur < *top)
         (*top)--;
       else if (cur - *top > dialw->ys - 3)
         (*top)++;
       prdir(dialw, *top, *top);
-      wcurbar(dialw, cur + 1 - *top, XA_REVERSE | stdattr);
+      mc_wcurbar(dialw, cur + 1 - *top, XA_REVERSE | stdattr);
       ocur = cur;
     } /* end redraw condition */
   }   /* end loop   */
@@ -1355,7 +1417,7 @@ static void dial_entry(struct dialent *d)
     mode_status();
   }
   newtype = d->term;
-  vt_set(-1, d->flags & FL_WRAP, NULL, -1, -1, d->flags & FL_ECHO, -1, -1);
+  vt_set(-1, d->flags & FL_WRAP, -1, -1, d->flags & FL_ECHO, -1, -1);
   local_echo = d->flags & FL_ECHO;
   if (newtype != terminal)
     init_emul(newtype, 1);
@@ -1477,12 +1539,12 @@ void dialdir(void)
   dirflush = 0;
   x1 = (COLS / 2) - 37;
   x2 = (COLS / 2) + 37;
-  dsub = wopen(x1 - 1, LINES - 3, x2 + 1, LINES - 3, BNONE,
+  dsub = mc_wopen(x1 - 1, LINES - 3, x2 + 1, LINES - 3, BNONE,
                XA_REVERSE | stdattr, mfcolor, mbcolor, 0, 0, 1);
-  w = wopen(x1, 2, x2, LINES - 6, BSINGLE, stdattr, mfcolor, mbcolor, 0, 0, 1);
-  wcursor(w, CNONE);
-  wtitle(w, TMID, _("Dialing Directory"));
-  wputs(w,
+  w = mc_wopen(x1, 2, x2, LINES - 6, BSINGLE, stdattr, mfcolor, mbcolor, 0, 0, 1);
+  mc_wcursor(w, CNONE);
+  mc_wtitle(w, TMID, _("Dialing Directory"));
+  mc_wputs(w,
         _("     Name            Number            Last on      Times Script\n"));
   for (i = 0; i < DIALOPTS; i++) {
     const char *str, *c;
@@ -1499,24 +1561,24 @@ void dialdir(void)
     what_padding[i][1] = j / 2; /* Rounding down */
     what_padding[i][0] = j - what_padding[i][1]; /* >= 1 */
   }
-  wlocate(dsub, position_dialing_directory, 0);
+  mc_wlocate(dsub, position_dialing_directory, 0);
   for (i = 0; i < DIALOPTS; i++)
     horiz_draw(i);
 
-  wsetregion(w, 1, w->ys - 1);
+  mc_wsetregion(w, 1, w->ys - 1);
   w->doscroll = 0;
 
   prdir(w, top, top);
-  wlocate(w, position_dialing_directory, w->ys - 1);
-  wprintf(w, "%*.*s", tagmvlen,tagmvlen, tag_exit);
+  mc_wlocate(w, position_dialing_directory, w->ys - 1);
+  mc_wprintf(w, "%*.*s", tagmvlen,tagmvlen, tag_exit);
   dhili(position_dialing_directory, subm);
   dirflush = 1;
-  wredraw(dsub, 1);
+  mc_wredraw(dsub, 1);
 
 again:
-  wcurbar(w, cur + 1 - top, XA_REVERSE | stdattr);
+  mc_wcurbar(w, cur + 1 - top, XA_REVERSE | stdattr);
   if (first) {
-    wredraw(w, 1);
+    mc_wredraw(w, 1);
     first = 0;
   }
   while(!quit) {
@@ -1551,11 +1613,11 @@ again:
         quit = 1;
         break;
       case ' ':    /* Tag. */
-        wlocate(w, 4, cur + 1 - top);
+        mc_wlocate(w, 4, cur + 1 - top);
         d->flags ^= FL_TAG;
-        wsetattr(w, XA_REVERSE | stdattr);
-        wprintf(w, "%c", d->flags & FL_TAG ? '>' : ' ');
-        wsetattr(w, XA_NORMAL | stdattr);
+        mc_wsetattr(w, XA_REVERSE | stdattr);
+        mc_wprintf(w, "%c", d->flags & FL_TAG ? '>' : ' ');
+        mc_wsetattr(w, XA_NORMAL | stdattr);
         cur += (cur < nrents - 1);
         break;
       case '\033':
@@ -1575,7 +1637,7 @@ again:
     }
     /* Decide if we have to delete the cursor bar */
     if (cur != ocur || quit == 1)
-      wcurbar(w, ocur + 1 - top, XA_NORMAL | stdattr);
+      mc_wcurbar(w, ocur + 1 - top, XA_NORMAL | stdattr);
 
     if (cur < top) {
       top--;
@@ -1586,7 +1648,7 @@ again:
       prdir(w, top, top);
     }
     if (cur != ocur)
-      wcurbar(w, cur + 1 - top, XA_REVERSE | stdattr);
+      mc_wcurbar(w, cur + 1 - top, XA_REVERSE | stdattr);
     ocur = cur;
     dhili(position_dialing_directory, subm);
   }
@@ -1595,8 +1657,8 @@ again:
   if (c == '\033') {
     if (changed)
       writedialdir();
-    wclose(w, 1);
-    wclose(dsub, 1);
+    mc_wclose(w, 1);
+    mc_wclose(dsub, 1);
     return;
   }
   /* Page up or down ? */
@@ -1630,8 +1692,8 @@ again:
 
   /* Dial an entry */
   if (subm == 0) {
-    wclose(w, 1);
-    wclose(dsub, 1);
+    mc_wclose(w, 1);
+    mc_wclose(dsub, 1);
     if (changed)
       writedialdir();
 
@@ -1665,7 +1727,7 @@ again:
       if (strstr(d->name, s))
         break;
     if (d == NULL) {
-      wbell();
+      mc_wbell();
       goto again;
     }
     /* Set current to found entry. */
@@ -1689,7 +1751,7 @@ again:
   if (subm == 2) {
     d1 = mkstdent();
     if (d1 == (struct dialent *)0) {
-      wbell();
+      mc_wbell();
       goto again;
     }
     changed++;
@@ -1712,8 +1774,8 @@ again:
   if (subm == 3) {
     dedit(d);
     changed++;
-    wlocate(w, 0, cur + 1 - top);
-    wprintf(w, fmt, cur+1, (d->flags & FL_TAG) ? 16 : ' ', d->name,
+    mc_wlocate(w, 0, cur + 1 - top);
+    mc_wprintf(w, fmt, cur+1, (d->flags & FL_TAG) ? 16 : ' ', d->name,
             d->number, d->lastdate, d->lasttime, d->count, d->script);
   }
 
@@ -1742,22 +1804,22 @@ again:
       prdir(w, top, cur);
     }
     if (nrents - top <= w->ys - 3) {
-      wlocate(w, 0, nrents - top + 1);
-      wclreol(w);
+      mc_wlocate(w, 0, nrents - top + 1);
+      mc_wclreol(w);
     }
     ocur = cur;
   }
 
   /* Move the entry up/down in directory. */
   if (subm == 5) {
-    wlocate(w, position_dialing_directory, w->ys - 1);
-    wprintf(w, "%*.*s", tagmvlen,tagmvlen, move_exit);
+    mc_wlocate(w, position_dialing_directory, w->ys - 1);
+    mc_wprintf(w, "%*.*s", tagmvlen,tagmvlen, move_exit);
     cur = move_entry (w, d, cur, &top);
     if (cur != ocur)
       changed++;
     ocur = cur;
-    wlocate(w, position_dialing_directory, w->ys - 1);
-    wprintf(w, "%*.*s", tagmvlen,tagmvlen, tag_exit);
+    mc_wlocate(w, position_dialing_directory, w->ys - 1);
+    mc_wprintf(w, "%*.*s", tagmvlen,tagmvlen, tag_exit);
   }
 
   /* Dial a number manually. */
@@ -1766,8 +1828,8 @@ again:
     if (s && *s) {
       if (changed)
         writedialdir();
-      wclose(w, 1);
-      wclose(dsub, 1);
+      mc_wclose(w, 1);
+      mc_wclose(dsub, 1);
 
       strncpy(d_man->number, manual, sizeof(d_man->number));
       dial(d_man, (struct dialent**)NULL);
