@@ -14,13 +14,18 @@
  *	modify it under the terms of the GNU General Public License
  *	as published by the Free Software Foundation; either version
  *	2 of the License, or (at your option) any later version.
+ *
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
  */
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
 #include "rcsid.h"
-RCSID("$Id: file.c,v 1.10 2005/08/14 20:39:30 al-guest Exp $")
+RCSID("$Id: file.c,v 1.13 2007-10-10 20:18:20 al-guest Exp $")
 
 #include "port.h"
 #include "minicom.h"
@@ -81,7 +86,7 @@ static void file_tell(const char *s)
 
   w = mc_tell("%s", s);
   sleep(1);
-  wclose(w, 1);
+  mc_wclose(w, 1);
 }
 
 /* Draw an entry in the horizontal menu */
@@ -89,11 +94,11 @@ static void horiz_draw(size_t k, char start_attr, char end_attr)
 {
   static const char spaces[] = "        ";
 
-  wprintf(dsub, "%.*s", what_padding[k][0], spaces);
-  wsetattr(dsub, start_attr);
-  wprintf(dsub, "%.*s", what_lens[k], _(what[k]));
-  wsetattr(dsub, end_attr);
-  wprintf(dsub, "%.*s", what_padding[k][1], spaces);
+  mc_wprintf(dsub, "%.*s", what_padding[k][0], spaces);
+  mc_wsetattr(dsub, start_attr);
+  mc_wprintf(dsub, "%.*s", what_lens[k], _(what[k]));
+  mc_wsetattr(dsub, end_attr);
+  mc_wprintf(dsub, "%.*s", what_padding[k][1], spaces);
 }
 
 /*
@@ -108,17 +113,17 @@ static void dhili(int k)
     return;
 
   if (dprev >= 0) {
-    wlocate(dsub, initial_y + WHAT_WIDTH * dprev, 0);
+    mc_wlocate(dsub, initial_y + WHAT_WIDTH * dprev, 0);
     if (!useattr)
-      wputs(dsub, " ");
+      mc_wputs(dsub, " ");
     else
       horiz_draw(dprev, stdattr, stdattr);
   }
   dprev = k;
 
-  wlocate(dsub, initial_y + WHAT_WIDTH * k, 0);
+  mc_wlocate(dsub, initial_y + WHAT_WIDTH * k, 0);
   if (!useattr)
-    wputs(dsub, ">");
+    mc_wputs(dsub, ">");
   else
     horiz_draw(k, XA_REVERSE | stdattr, stdattr);
 }
@@ -155,22 +160,22 @@ static void prdir(WIN *dirw, int top, int cur,
   start = cur - top;
   dirflush = 0;
   sprintf(f_str, " %%-%ds", longest + 2);
-  wlocate(dirw, 0, start + FILE_MWTR);
+  mc_wlocate(dirw, 0, start + FILE_MWTR);
   for (f = start; f < dirw->ys - (1 + FILE_MWTR); f++) {
     if ((d = getno(f + top, dirdat)) == (GETSDIR_ENTRY *)NULL)
       break;
     if (d->cflags & FL_TAG)
-      wsetattr(dirw, XA_REVERSE | stdattr);
+      mc_wsetattr(dirw, XA_REVERSE | stdattr);
     if (S_ISDIR(d->mode)) {
       snprintf(t_str, sizeof(t_str), "[%s]", d->fname);
-      wprintf(dirw, f_str, t_str);
+      mc_wprintf(dirw, f_str, t_str);
     } else
-      wprintf(dirw, f_str, d->fname);
-    wsetattr(dirw, XA_NORMAL | stdattr);
-    wputc(dirw, '\n');
+      mc_wprintf(dirw, f_str, d->fname);
+    mc_wsetattr(dirw, XA_NORMAL | stdattr);
+    mc_wputc(dirw, '\n');
   }
   dirflush = 1;
-  wflush();
+  mc_wflush();
 }
 
 /*
@@ -185,18 +190,18 @@ static void prone(WIN *dirw, GETSDIR_ENTRY *dirdat, int longest, int inverse)
   sprintf(f_str, " %%-%ds", longest + 2);
   /*
   if (dirdat->cflags & FL_TAG)
-    wsetattr(dirw, XA_REVERSE | stdattr);
+    mc_wsetattr(dirw, XA_REVERSE | stdattr);
      */
   if (inverse)
-    wsetattr(dirw, XA_REVERSE | stdattr);
+    mc_wsetattr(dirw, XA_REVERSE | stdattr);
   if (S_ISDIR(dirdat->mode)) {
     snprintf(t_str, sizeof(t_str),  "[%s]", dirdat->fname);
-    wprintf(dirw, f_str, t_str);
+    mc_wprintf(dirw, f_str, t_str);
   } else
-    wprintf(dirw, f_str, dirdat->fname);
-  wsetattr(dirw, XA_NORMAL | stdattr);
+    mc_wprintf(dirw, f_str, dirdat->fname);
+  mc_wsetattr(dirw, XA_NORMAL | stdattr);
   dirflush = 1;
-  wflush();
+  mc_wflush();
 }
 
 static WIN *main_w;
@@ -252,7 +257,7 @@ static void *set_work_dir(void *existing, size_t min_len)
   void *vp;
 
   vp = existing == NULL
-       ? (void *)malloc(min_len) : (void *)realloc(existing, min_len);
+       ? malloc(min_len) : realloc(existing, min_len);
 
   if (down_loading)
     d_work_dir = vp;
@@ -330,11 +335,11 @@ static int new_filedir(GETSDIR_ENTRY *o_dirdat, int flushit)
 
   if (flushit) {
     dirflush = 0;
-    winclr(main_w);
-    wredraw(main_w, 1);
+    mc_winclr(main_w);
+    mc_wredraw(main_w, 1);
   }
 
-  wcursor(main_w, CNORMAL);
+  mc_wcursor(main_w, CNORMAL);
 
   {
     char *s;
@@ -357,7 +362,7 @@ static int new_filedir(GETSDIR_ENTRY *o_dirdat, int flushit)
     snprintf(file_title, sizeof(file_title), "%s", s);
   }
 
-  wtitle(main_w, TMID, file_title);
+  mc_wtitle(main_w, TMID, file_title);
   if ((new_dp_len = strlen(work_dir)) > dp_len) {
     dp_len = new_dp_len;
     snprintf(cwd_str_fmt, sizeof(cwd_str_fmt),
@@ -366,20 +371,21 @@ static int new_filedir(GETSDIR_ENTRY *o_dirdat, int flushit)
   new_dp_len = mbslen (work_dir);
   if (new_dp_len + (fmt_len = mbslen(cwd_str_fmt)) > 75) {
     size_t i;
+    char *tmp_dir = work_dir;
 
     /* We want the last 73 characters */
     for (i = 0; 73 + i < new_dp_len + fmt_len; i++) {
       wchar_t wc;
 
-      work_dir += one_mbtowc(&wc, work_dir, MB_LEN_MAX);
+      tmp_dir += one_mbtowc(&wc, work_dir, MB_LEN_MAX);
     }
-    snprintf(disp_dir, sizeof(disp_dir), "...%s", work_dir);
+    snprintf(disp_dir, sizeof(disp_dir), "...%s", tmp_dir);
     snprintf(cwd_str, sizeof(cwd_str), cwd_str_fmt, disp_dir);
   } else
     snprintf(cwd_str, sizeof(cwd_str), cwd_str_fmt, work_dir);
 
-  wlocate(main_w, 0, 0);
-  wputs(main_w, cwd_str);
+  mc_wlocate(main_w, 0, 0);
+  mc_wputs(main_w, cwd_str);
 
   for (i = 0; i < WHAT_NR_OPTIONS; i++) {
     const char *str, *c;
@@ -396,11 +402,11 @@ static int new_filedir(GETSDIR_ENTRY *o_dirdat, int flushit)
     what_padding[i][1] = j / 2; /* Rounding down */
     what_padding[i][0] = j - what_padding[i][1]; /* >= 1 */
   }
-  wlocate(dsub, initial_y, 0);
+  mc_wlocate(dsub, initial_y, 0);
   for (i = 0; i < WHAT_NR_OPTIONS; i++)
-    horiz_draw(i, wgetattr(dsub), wgetattr(dsub));
+    horiz_draw(i, mc_wgetattr(dsub), mc_wgetattr(dsub));
 
-  wsetregion(main_w, 1, main_w->ys - FILE_MWTR);
+  mc_wsetregion(main_w, 1, main_w->ys - FILE_MWTR);
   main_w->doscroll = 0;
 
   /* old dir to discard? */
@@ -412,21 +418,21 @@ static int new_filedir(GETSDIR_ENTRY *o_dirdat, int flushit)
                         GETSDIR_PARNT|GETSDIR_NSORT|GETSDIR_DIRSF,
                         0, &dirdat, &longest)) < 0) {
     /* we really want to announce the error here!!! */
-    wclose(main_w, 1);
-    wclose(dsub, 1);
+    mc_wclose(main_w, 1);
+    mc_wclose(dsub, 1);
     free(dirdat);
     return -1;
   }
 
   prdir(main_w, top, top, dirdat, longest);  
-  wlocate(main_w, initial_y, main_w->ys - FILE_MWTR);
-  wputs(main_w, _("( Escape to exit, Space to tag )"));
+  mc_wlocate(main_w, initial_y, main_w->ys - FILE_MWTR);
+  mc_wputs(main_w, _("( Escape to exit, Space to tag )"));
   dhili(subm);
   /* this really needs to go in dhili !!!*/
-  wlocate(main_w, 0, cur + FILE_MWTR - top);
+  mc_wlocate(main_w, 0, cur + FILE_MWTR - top);
   if (flushit) {
     dirflush = 1;
-    wredraw(dsub, 1);
+    mc_wredraw(dsub, 1);
   }
 
   return 0;
@@ -487,16 +493,16 @@ static int init_filedir(void)
   dirflush = 0;
   x1 = (COLS / 2) - 37;
   x2 = (COLS / 2) + 37;
-  dsub = wopen(x1 - 1, LINES - 3, x2 + 1, LINES - 3, BNONE, 
+  dsub = mc_wopen(x1 - 1, LINES - 3, x2 + 1, LINES - 3, BNONE, 
                stdattr, mfcolor, mbcolor, 0, 0, 1);
-  main_w = wopen(x1, 2, x2, LINES - 6, BSINGLE, stdattr, mfcolor,
+  main_w = mc_wopen(x1, 2, x2, LINES - 6, BSINGLE, stdattr, mfcolor,
                  mbcolor, 0, 0, 1);
 
   if (ret_buf != NULL ||
       (retstat = ((ret_buf = (char *)malloc(BUFSIZ)) == NULL)? -1 : 0) == 0) {
     retstat = new_filedir((GETSDIR_ENTRY *) NULL, 0);
     dirflush = 1;
-    wredraw(dsub, 1);
+    mc_wredraw(dsub, 1);
   }
   return retstat;
 }
@@ -582,9 +588,9 @@ char * filedir(int howmany, int downloading)
   init_filedir();
 
 again:
-  wlocate(main_w, 0, cur + FILE_MWTR - top);
+  mc_wlocate(main_w, 0, cur + FILE_MWTR - top);
   if (first) {
-    wredraw(main_w, 1);
+    mc_wredraw(main_w, 1);
     first = 0;
   }
   while (!quit) {
@@ -651,9 +657,9 @@ again:
               ++tag_cnt;
             } else
               --tag_cnt;
-            wlocate(main_w, 0, cur + FILE_MWTR - top);
+            mc_wlocate(main_w, 0, cur + FILE_MWTR - top);
             prone(main_w, d, longest, d->cflags & FL_TAG);
-            wputc(main_w, '\n');
+            mc_wputc(main_w, '\n');
             cur += cur < nrents - 1;
           }
         }
@@ -691,20 +697,20 @@ again:
     }
     /*
      if(cur != ocur)
-     wlocate(main_w, 0, cur + FILE_MWTR - top);
+     mc_wlocate(main_w, 0, cur + FILE_MWTR - top);
      */
 
     ocur = cur;
     dhili(subm);
     /* this really needs to go in dhili !!!*/
-    wlocate(main_w, 0, cur + FILE_MWTR - top);
+    mc_wlocate(main_w, 0, cur + FILE_MWTR - top);
   }
 
   quit = 0;
   /* ESC means quit */
   if (c == '\033') {
-    wclose(main_w, 1);
-    wclose(dsub, 1);
+    mc_wclose(main_w, 1);
+    mc_wclose(dsub, 1);
     free(dirdat);
     return NULL;
   }
@@ -861,8 +867,8 @@ untag_end:
             }
           }
 
-          wclose(main_w, 1);
-          wclose(dsub, 1);
+          mc_wclose(main_w, 1);
+          mc_wclose(dsub, 1);
           free(dirdat);
           return ret_ptr;
         }
