@@ -12,6 +12,11 @@
  *		as published by the Free Software Foundation; either version
  *		2 of the License, or (at your option) any later version.
  *
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ *
  *  // jl 23.06.97 adjustable DTR drop time
  */
 #ifdef HAVE_CONFIG_H
@@ -19,7 +24,7 @@
 #endif
 
 #include "rcsid.h"
-RCSID("$Id: functions.c,v 1.2 2003/07/20 18:55:40 al-guest Exp $")
+RCSID("$Id: functions.c,v 1.3 2007-10-10 20:18:20 al-guest Exp $")
 
 #include "port.h"
 #include "minicom.h"
