@@ -10,6 +10,10 @@
  *	as published by the Free Software Foundation; either version
  *	2 of the License, or (at your option) any later version.
  *
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
  *	Note: this code uses "wildmat.c", which has different copyright
  *	and licensing conditions.  See the source, Luke.
  */
@@ -18,7 +22,7 @@
 #endif
 
 #include "rcsid.h"
-RCSID("$Id: getsdir.c,v 1.3 2005/08/04 20:33:33 al-guest Exp $")
+RCSID("$Id: getsdir.c,v 1.5 2007-10-10 20:18:20 al-guest Exp $")
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -148,23 +152,14 @@ int getsdir(const char *dirpath, const char *pattern, int sortflags,
   datb_cur  = (DAT_BUF *) NULL;
 
   /* open the specified directory */
-  if ((dirp = opendir(dirpath)) == NULL)	
+  if ((dirp = opendir(dirpath)) == NULL)
     return -1;
 
-  /* discard current, and possibly parent, dir entries */
-  if (readdir(dirp) == NULL || 
-      (!(sortflags & GETSDIR_PARNT) && readdir(dirp) == NULL)) {
-    fprintf(stderr, _("DBUG: initial readdir() failed (errno == %d)\n"),
-            errno);
-    perror("readdir");
-    fflush(stderr);
-  }
-
-  for(cnt = 1;; ++cnt) {        /* for buffer count 1 to whatever... */
+  for (cnt = 1; ; ++cnt) {        /* for buffer count 1 to whatever... */
     datb_sav = datb_cur;	/* save pointer to previous buffer */
 
     /* get a new buffer */
-    if ((datb_cur = (DAT_BUF*)calloc(1, sizeof(DAT_BUF))) == NULL) {
+    if ((datb_cur = calloc(1, sizeof(DAT_BUF))) == NULL) {
       closedir(dirp);
       return -1;
     }
@@ -172,22 +167,24 @@ int getsdir(const char *dirpath, const char *pattern, int sortflags,
     /* init new buffer link pointer */
     datb_cur->nxt = NULL;
 
-    if (datb_frst == NULL)      	/* if first buff... */
+    if (datb_frst == NULL)		/* if first buff... */
       datb_frst = datb_cur;		/* ...init first buff pointer */
     else				/* else... */
       datb_sav->nxt = datb_cur;		/* ...link to new */
 
     /* while the current buffer is not full, get directory entries */
     for (datb_cur->cnt = 0; datb_cur->cnt < MAX_CNT;)
-      if ((dp = readdir(dirp)) != NULL) {/* get next directory entry */
-        if ((sortflags & GETSDIR_PARNT) && strcmp(dp->d_name, "..") == 0)
+      if ((dp = readdir(dirp))) {/* get next directory entry */
+	if (!strcmp(dp->d_name, "."))
+	  continue;
+        if ((sortflags & GETSDIR_PARNT) && !strcmp(dp->d_name, ".."))
           cmprstat = 1;
         else if (pattern && strlen(pattern))
           cmprstat = wildmat(dp->d_name, pattern);
         else
           cmprstat = 1;
 
-        if (cmprstat) {         	/* matching name? */
+        if (cmprstat) {			/* matching name? */
           int l;
 
           /* copy the filename */
