@@ -1,11 +1,8 @@
-/* $Id: intl.h,v 1.1.1.1 2003/03/30 18:55:51 al-guest Exp $ */
+/* $Id: intl.h,v 1.2 2007/01/07 15:47:14 al-guest Exp $ */
 
 #ifdef HAVE_LOCALE_H
 # include <locale.h>
 #endif
-#if !HAVE_SETLOCALE
-# define setlocale(Category, Locale) /* empty */
-#endif
 
 #define N_(Str) (Str)
 
