@@ -14,13 +14,16 @@
  *		modify it under the terms of the GNU General Public License
  *		as published by the Free Software Foundation; either version
  *		2 of the License, or (at your option) any later version.
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
 #include "rcsid.h"
-RCSID("$Id: ipc.c,v 1.9 2005/10/31 10:31:38 al-guest Exp $")
+RCSID("$Id: ipc.c,v 1.12 2007-10-10 20:18:20 al-guest Exp $")
 
 #include <strings.h>
 
@@ -68,7 +71,7 @@ int check_io(int fd1, int fd2, int tmout, char *buf, int *buflen)
       *buflen = i;
   }
 
-  return(n);
+  return n;
 }
 
 int keyboard(int cmd, int arg)
@@ -85,13 +88,13 @@ int keyboard(int cmd, int arg)
       escape = arg;
       break;
     case KSETBS:
-      vt_set(-1, -1, NULL, -1, arg, -1, -1, -1);
+      vt_set(-1, -1, -1, arg, -1, -1, -1);
       break;
     case KCURST:
-      vt_set(-1, -1, NULL, -1, -1, -1, NORMAL, -1);
+      vt_set(-1, -1, -1, -1, -1, NORMAL, -1);
       break;
     case KCURAPP:
-      vt_set(-1, -1, NULL, -1, -1, -1, APPL, -1);
+      vt_set(-1, -1, -1, -1, -1, APPL, -1);
       break;
     default:
       /* The rest is only meaningful if a keyserv runs. */
