@@ -9,6 +9,10 @@
  *		as published by the Free Software Foundation; either version
  *		2 of the License, or (at your option) any later version.
  *
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
  * fmg 1/11/94 color mods
  * jl  22.06.97 log it when DCD drops
  * jl  02.06.98 added call duration to the "Gone offline" log line
@@ -20,11 +24,12 @@
 #endif
 
 #include "rcsid.h"
-RCSID("$Id: main.c,v 1.16 2005/10/31 12:13:51 al-guest Exp $")
+RCSID("$Id: main.c,v 1.23 2008-02-02 22:49:53 al-guest Exp $")
 
 #include "port.h"
 #include "minicom.h"
 #include "intl.h"
+#include "sysdep.h"
 #ifdef HAVE_ERRNO_H
 #include <errno.h>
 #endif
@@ -75,7 +80,7 @@ char *mbasename(char *s, char *res, int reslen)
 void leave(const char *s)
 {
   if (stdwin)
-    wclose(stdwin, 1);
+    mc_wclose(stdwin, 1);
   if (portfd > 0) {
     m_restorestate(portfd);
     close(portfd);
@@ -150,8 +155,10 @@ void term_socket_close(void)
 
 /*
  * Open the terminal.
+ *
+ * \return -1 on error, 0 on success
  */
-int open_term(int doinit)
+int open_term(int doinit, int show_win_on_error)
 {
   struct stat stt;
   char buf[128];
@@ -207,7 +214,7 @@ int open_term(int doinit)
     }
     if (n == 0) {
       if (stdwin)
-        wclose(stdwin, 1);
+        mc_wclose(stdwin, 1);
       fprintf(stderr, _("Device %s is locked.\n"), dial_tty);
       drop_privs();
       return -1;
@@ -223,7 +230,7 @@ int open_term(int doinit)
       if ((fd = open(lockfile, O_WRONLY | O_CREAT | O_EXCL, 0666)) < 0) {
 #endif
         if (stdwin)
-          wclose(stdwin, 1);
+          mc_wclose(stdwin, 1);
         fprintf(stderr, _("Cannot create lockfile. Sorry.\n"));
         drop_privs();
         return -1;
@@ -240,7 +247,7 @@ int open_term(int doinit)
     if (doinit > 0 && P_CALLOUT[0]) {
       if (fastsystem(P_CALLOUT, NULL, NULL, NULL) < 0) {
         if (stdwin)
-          wclose(stdwin, 1);
+          mc_wclose(stdwin, 1);
         fprintf(stderr, _("Could not setup for dial out.\n"));
         if (lockfile[0])
           unlink(lockfile);
@@ -295,7 +302,7 @@ int open_term(int doinit)
   if (portfd < 0 && !portfd_is_socket) {
     if (doinit > 0) {
       if (stdwin)
-	wclose(stdwin, 1);
+	mc_wclose(stdwin, 1);
 #ifdef HAVE_ERRNO_H
       fprintf(stderr, _("minicom: cannot open %s: %s\n"),
                       dial_tty, strerror(s_errno));
@@ -309,7 +316,8 @@ int open_term(int doinit)
     }
     if (lockfile[0])
       unlink(lockfile);
-    werror(_("Cannot open %s!"), dial_tty);
+    if (show_win_on_error)
+      werror(_("Cannot open %s!"), dial_tty);
     drop_privs();
     return -1;
   }
@@ -372,7 +380,7 @@ void init_emul(int type, int do_init)
   int ypos;
 
   if (st) {
-    wclose(st, 1);
+    mc_wclose(st, 1);
     tempst = 0;
     st = NULL;
   }
@@ -381,7 +389,7 @@ void init_emul(int type, int do_init)
     x = us->curx;
     y = us->cury;
     attr = us->attr;
-    wclose(us, 0);
+    mc_wclose(us, 0);
   }
 
   /* See if we have space for a fixed status line */
@@ -395,9 +403,9 @@ void init_emul(int type, int do_init)
       ypos = LINES - 1;
       maxy = LINES - 2;
     }
-    st = wopen(0, ypos, COLS - 1, ypos, BNONE,
+    st = mc_wopen(0, ypos, COLS - 1, ypos, BNONE,
                st_attr, sfcolor, sbcolor, 1, 0, 1);
-    wredraw(st, 1);
+    mc_wredraw(st, 1);
   }
 
   /* MARK updated 02/17/95 - Customizable size for history buffer */
@@ -408,12 +416,12 @@ void init_emul(int type, int do_init)
     num_hist_lines = 5000;
 
   /* Open a new main window, and define the configured history buffer size. */
-  us = wopen(0, 0, COLS - 1, maxy,
+  us = mc_wopen(0, 0, COLS - 1, maxy,
               BNONE, XA_NORMAL, tfcolor, tbcolor, 1, num_hist_lines, 0);
 
   if (x >= 0) {
-    wlocate(us, x, y);
-    wsetattr(us, attr);
+    mc_wlocate(us, x, y);
+    mc_wsetattr(us, attr);
   }
 
   us->autocr = 0;
@@ -440,8 +448,8 @@ void init_emul(int type, int do_init)
  */
 static void ret_csr(void)
 {
-  wlocate(us, us->curx, us->cury);
-  wflush();
+  mc_wlocate(us, us->curx, us->cury);
+  mc_wflush();
 }
 
 /*
@@ -450,14 +458,14 @@ static void ret_csr(void)
 void mode_status(void)
 {
   if (st) { /* if swich off status line - NOT print !!! (vlk@st.simbirsk.su) */
-    wlocate(st, 20, 0);
+    mc_wlocate(st, 20, 0);
     if (portfd_is_socket) {
-      wprintf(st, "unix-socket");
+      mc_wprintf(st, "unix-socket");
     } else {
       if (P_SHOWSPD[0] == 'l')
-        wprintf(st, "%6ld %s%s%s", linespd, P_BITS, P_PARITY, P_STOPB);
+        mc_wprintf(st, "%6ld %s%s%s", linespd, P_BITS, P_PARITY, P_STOPB);
       else
-        wprintf(st, "%6.6s %s%s%s", P_BAUDRATE, P_BITS, P_PARITY, P_STOPB);
+        mc_wprintf(st, "%6.6s %s%s%s", P_BAUDRATE, P_BITS, P_PARITY, P_STOPB);
     }
     ret_csr();
   }
@@ -472,11 +480,11 @@ void time_status(void)
 {
   if (!st || disable_online_time)
     return;
-  wlocate(st, 63, 0);
+  mc_wlocate(st, 63, 0);
   if (online < 0)
-    wprintf(st, " %12.12s ", P_HASDCD[0] == 'Y' ? _("Offline") : _("OFFLINE"));
+    mc_wprintf(st, " %12.12s ", P_HASDCD[0] == 'Y' ? _("Offline") : _("OFFLINE"));
   else
-    wprintf(st, " %s %02ld:%02ld", P_HASDCD[0] == 'Y' ? _("Online") : _("ONLINE"),
+    mc_wprintf(st, " %s %02ld:%02ld", P_HASDCD[0] == 'Y' ? _("Online") : _("ONLINE"),
             online / 3600, (online / 60) % 60);
 
   ret_csr();
@@ -487,8 +495,8 @@ void time_status(void)
  */
 void curs_status(void)
 {
-  wlocate(st, 33, 0);
-  wprintf(st, cursormode == NORMAL ? "NOR" : "APP");
+  mc_wlocate(st, 33, 0);
+  mc_wprintf(st, cursormode == NORMAL ? "NOR" : "APP");
   ret_csr();
 }
 
@@ -511,7 +519,23 @@ static void updtime(void)
     time_status();
     ret_csr();
   }
-  wflush();
+  mc_wflush();
+}
+
+/**
+ * Get status of device. It might happen that the device disappears (e.g.
+ * due to a USB-serial unplug).
+ *
+ * \return 1 if device seems ok, 0 if it seems not available
+ */
+static int get_device_status(int fd)
+{
+  struct termios t;
+  if (fd < 0)
+    return 0;
+  if (portfd_is_socket && portfd_is_connected)
+    return 1;
+  return !tcgetattr(fd, &t);
 }
 
 /* Update the timer display. This can also be called from updown.c */
@@ -521,7 +545,8 @@ void timer_update(void)
   int dcd_support = P_HASDCD[0] == 'Y';
 
   /* See if we're online. */
-  if ((!dcd_support && bogus_dcd) || (dcd_support && m_getdcd(portfd))) {
+  if ((!dcd_support && bogus_dcd)
+      || (dcd_support && m_getdcd(portfd) == 1)) {
     /* We are online at the moment. */
     if (online < 0) {
       /* This was a transition from off to online */
@@ -569,23 +594,23 @@ void timer_update(void)
 void show_status(void)
 {
   st->direct = 0;
-  wlocate(st, 0, 0);
-  wprintf(st,
+  mc_wlocate(st, 0, 0);
+  mc_wprintf(st,
           _(" %7.7sZ for help |           |     | Minicom %-6.6s |       | "),
           esc_key(), VERSION);
   mode_status();
   time_status();
   curs_status();
-  wlocate(st, 56, 0);
+  mc_wlocate(st, 56, 0);
   switch(terminal) {
     case VT100:
-      wputs(st, "VT102");
+      mc_wputs(st, "VT102");
       break;
     case ANSI:
-      wputs(st, "ANSI");
+      mc_wputs(st, "ANSI");
       break;
   }
-  wredraw(st, 1);
+  mc_wredraw(st, 1);
   ret_csr();
 }
 
@@ -596,11 +621,11 @@ void scriptname(const char *s)
 {
   if (st == NULL)
     return;
-  wlocate(st, 39, 0);
+  mc_wlocate(st, 39, 0);
   if (*s == 0)
-    wprintf(st, "Minicom %-6.6s", VERSION);
+    mc_wprintf(st, "Minicom %-6.6s", VERSION);
   else
-    wprintf(st, "script %-7.7s", s);
+    mc_wprintf(st, "script %-7.7s", s);
   ret_csr();
 }
 
@@ -612,7 +637,7 @@ static void showtemp(void)
   if (st)
     return;
 
-  st = wopen(0, LINES - 1, COLS - 1, LINES - 1,
+  st = mc_wopen(0, LINES - 1, COLS - 1, LINES - 1,
              BNONE, st_attr, sfcolor, sbcolor, 1, 0, 1);
   show_status();
   tempst = 1;
@@ -620,7 +645,7 @@ static void showtemp(void)
 
 /*
  * The main terminal loop:
- *	- If there are characters recieved send them
+ *	- If there are characters received send them
  *	  to the screen via the appropriate translate function.
  */
 int do_terminal(void)
@@ -635,6 +660,7 @@ int do_terminal(void)
   int zpos = 0;
   const char *s;
   dirflush = 0;
+  WIN *error_on_open_window = NULL;
 
 dirty_goto:
   /* Show off or online time */
@@ -643,7 +669,7 @@ dirty_goto:
   /* If the status line was shown temporarily, delete it again. */
   if (tempst) {
     tempst = 0;
-    wclose(st, 1);
+    mc_wclose(st, 1);
     st = NULL;
   }
 
@@ -663,12 +689,12 @@ dirty_goto:
       size_changed = 0;
 #if 1
       /* I got the resize code going again! Yeah! */
-      wclose(us, 0);
+      mc_wclose(us, 0);
       us = NULL;
       if (st)
-        wclose(st, 0);
+        mc_wclose(st, 0);
       st = NULL;
-      wclose(stdwin, 0);
+      mc_wclose(stdwin, 0);
       if (win_init(tfcolor, tbcolor, XA_NORMAL) < 0)
         leave(_("Could not re-initialize window system."));
       /* Set the terminal modes */
@@ -681,6 +707,19 @@ dirty_goto:
     /* Update the timer. */
     timer_update();
 
+    /* check if device is ok, if not, try to open it */
+    if (!get_device_status(portfd_connected)) {
+      if (open_term(0, 0) < 0) {
+	if (!error_on_open_window)
+          error_on_open_window = mc_tell(_("Cannot open %s!"), dial_tty);
+      } else {
+	if (error_on_open_window) {
+          mc_wclose(error_on_open_window, 1);
+	  error_on_open_window = NULL;
+	}
+      }
+    }
+
     /* Check for I/O or timer. */
     x = check_io(portfd_connected, 0, 1000, buf, &blen);
 
@@ -708,7 +747,7 @@ dirty_goto:
           goto dirty_goto;
         }
       }
-      wflush();
+      mc_wflush();
     }
 
     /* Read from the keyboard and send to modem. */
