@@ -10,6 +10,10 @@
  *		as published by the Free Software Foundation; either version
  *		2 of the License, or (at your option) any later version.
  *
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
  * fmg 1/11/94 colors
  * jl  30.06.97 log it if you quit without reset while online
  * fmg 8/20/97 History buffer searching added
@@ -24,7 +28,7 @@
 #endif
 
 #include "rcsid.h"
-RCSID(PKG_VER "$Id: minicom.c,v 1.29 2005/10/31 12:13:51 al-guest Exp $")
+RCSID(PKG_VER "$Id: minicom.c,v 1.34 2008-02-02 22:49:53 al-guest Exp $")
 
 #include <getopt.h>
 #include <wchar.h>
@@ -105,29 +109,33 @@ static void hangsig(int sig)
  * Jump to a shell
  */
 #ifdef SIGTSTP
-/*ARGSUSED*/
-static void shjump(int dummy /* __attribute__((unused)) */)
+static void shjump(int sig)
 {
-  dummy = dummy; /* avoid compiler warning, should be optimized away... */
-  wleave();
+  sigset_t ss, oldss;
+
+  (void)sig;
+  mc_wleave();
   signal(SIGTSTP, SIG_DFL);
+  sigemptyset(&ss);
+  sigaddset(&ss, SIGTSTP);
+  sigprocmask(SIG_UNBLOCK, &ss, &oldss);
   fputs(_("Suspended. Type \"fg\" to resume.\n"),stdout);
   kill(getpid(), SIGTSTP);
+  sigprocmask(SIG_SETMASK, &oldss, NULL);
   signal(SIGTSTP, shjump);
-  wreturn();
+  mc_wreturn();
   if (use_status)
     show_status();
 }
 #else
-/*ARGSUSED*/
-static void shjump(int dummy /* __attribute__((unused)) */)
+static void shjump(int sig)
 {
   char *sh;
   int pid;
   int status;
   int f;
 
-  dummy = dummy; /* avoid compiler warning, should be optimized away... */
+  (void)sig;
   sh = getenv("SHELL");
   if (sh == NULL) {
     werror(_("SHELL variable not set"));
@@ -138,7 +146,7 @@ static void shjump(int dummy /* __attribute__((unused)) */)
     return;
   }
   if (pid != 0)
-    wleave();
+    mc_wleave();
   if (pid == 0) {
     for (f = 1; f < _NSIG; f++)
       signal(f, SIG_DFL);
@@ -152,7 +160,7 @@ static void shjump(int dummy /* __attribute__((unused)) */)
     exit(1);
   }
   m_wait(&status);
-  wreturn();
+  mc_wreturn();
   if (use_status)
     show_status();
 }
@@ -197,9 +205,9 @@ static void drawhist(WIN *w, int y, int r)
 
   w->direct = 0;
   for (f = 0; f < w->ys; f++)
-    wdrawelm(w, f, getline(w, y++));
+    mc_wdrawelm(w, f, getline(w, y++));
   if (r)
-    wredraw(w, 1);
+    mc_wredraw(w, 1);
   w->direct = 1;
 }
 
@@ -222,19 +230,19 @@ void drawhist_look(WIN *w, int y, int r, wchar_t *look, int case_matters)
     tmp_e = getline(w, y++);
 
     /* First we "accumulate" the line into a variable */
-    wdrawelm_var(w, tmp_e, tmp_line);
+    mc_wdrawelm_var(w, tmp_e, tmp_line);
 
     /* Does it have what we want? */
     if (wcslen(look) > 1 && wcslen(tmp_line) > 1) {
       if (StrStr(tmp_line,look, case_matters))
-        wdrawelm_inverse(w, f, tmp_e); /* 'inverse' it */
+        mc_wdrawelm_inverse(w, f, tmp_e); /* 'inverse' it */
       else
-        wdrawelm(w, f, tmp_e); /* 'normal' output */
+        mc_wdrawelm(w, f, tmp_e); /* 'normal' output */
     }
   }
 
   if (r)
-    wredraw(w, 1);
+    mc_wredraw(w, 1);
   w->direct = 1;
 }
 
@@ -256,31 +264,31 @@ void searchhist(WIN *w_hist, wchar_t *str)
     y--;
 
   /* Open a Search line window. */
-  w_new = wopen(0, y+1, w_hist->x2, y+1, 0, st_attr, sfcolor, sbcolor, 0, 0, 1);
+  w_new = mc_wopen(0, y+1, w_hist->x2, y+1, 0, st_attr, sfcolor, sbcolor, 0, 0, 1);
   w_new->doscroll = 0;
   w_new->wrap = 0;
 
   hline = _("SEARCH FOR (ESC=Exit)");
-  wprintf(w_new, "%s(%d):",hline,MAX_SEARCH);
-  wredraw(w_new, 1);
-  wflush();
+  mc_wprintf(w_new, "%s(%d):",hline,MAX_SEARCH);
+  mc_wredraw(w_new, 1);
+  mc_wflush();
 
-  wlocate(w_new, mbslen(hline)+6, 0);
+  mc_wlocate(w_new, mbslen(hline)+6, 0);
   for (i = 0; str[i] != 0; i++)
-    wputc(w_new, str[i]);
-  wlocate(w_new, mbslen(hline)+6, 0);
-  wgetwcs(w_new, str, MAX_SEARCH, MAX_SEARCH);
+    mc_wputc(w_new, str[i]);
+  mc_wlocate(w_new, mbslen(hline)+6, 0);
+  mc_wgetwcs(w_new, str, MAX_SEARCH, MAX_SEARCH);
 #if 0
   if (!str[0]) { /* then unchanged... must have pressed ESC... get out */
-    wflush();
-    wclose(w_new, 0);
+    mc_wflush();
+    mc_wclose(w_new, 0);
     return;
   }
 #endif
 
-  wredraw(w_hist, 1);
-  wclose(w_new, 1);
-  wflush();
+  mc_wredraw(w_hist, 1);
+  mc_wclose(w_new, 1);
+  mc_wflush();
 
   return;
 }
@@ -322,7 +330,7 @@ int find_next(WIN *w, WIN *w_hist,
      * First we "accumulate" the line into a variable.
      * To see 'why', see what an 'ELM' structure looks like!
      */
-    wdrawelm_var(w, tmp_e, tmp_line);
+    mc_wdrawelm_var(w, tmp_e, tmp_line);
 
     /* Does it have what we want? */
     if (wcslen(tmp_line) > 1 && wcslen(look) > 1)
@@ -371,9 +379,9 @@ wchar_t *StrStr(wchar_t *str1, wchar_t *str2, int case_matters)
 static void drawcite(WIN *w, int y, int citey, int start, int end)
 {
   if (y+citey >= start && y+citey <= end)
-    wdrawelm_inverse(w, y, getline(w, y+citey));
+    mc_wdrawelm_inverse(w, y, getline(w, y+citey));
   else
-    wdrawelm(w, y, getline(w, y+citey));
+    mc_wdrawelm(w, y, getline(w, y+citey));
 }
 
 static void drawcite_whole(WIN *w, int y, int start, int end)
@@ -393,7 +401,7 @@ static void do_cite(WIN *w, int start, int end)
     vt_send('>');
     vt_send(' ');
     tmp_e = getline(w, y);
-    wdrawelm_var(w, tmp_e, tmp_line);
+    mc_wdrawelm_var(w, tmp_e, tmp_line);
     tmp_line[w->xs] = 0;
     for (x = w->xs-1; x >= 0; x--) {
       if (tmp_line[x] <= ' ')
@@ -439,12 +447,12 @@ static void scrollback(void)
     y--;
 
   /* Open a window. */
-  b_us = wopen(0, 0, us->x2, y, 0, us->attr, COLFG(us->color),
+  b_us = mc_wopen(0, 0, us->x2, y, 0, us->attr, COLFG(us->color),
                COLBG(us->color), 0, 0, 0);
-  wcursor(b_us, CNONE);
+  mc_wcursor(b_us, CNONE);
 
   /* Open a help line window. */
-  b_st = wopen(0, y+1, us->x2, y+1, 0, st_attr, sfcolor, sbcolor, 0, 0, 1);
+  b_st = mc_wopen(0, y+1, us->x2, y+1, 0, st_attr, sfcolor, sbcolor, 0, 0, 1);
   b_st->doscroll = 0;
   b_st->wrap = 0;
 
@@ -461,9 +469,9 @@ static void scrollback(void)
   if (b_st->xs < 127)
     hline0[b_st->xs] = 0;
   hline = hline0;
-  wprintf(b_st, hline);
-  wredraw(b_st, 1);
-  wflush();
+  mc_wprintf(b_st, hline);
+  mc_wredraw(b_st, 1);
+  mc_wflush();
 
   /* And do the job. */
   y = us->histlines;
@@ -494,12 +502,12 @@ static void scrollback(void)
       case '/':
       case 's':
         if (!us->histlines) {
-          wbell();
+          mc_wbell();
           werror(_("History buffer Disabled!"));
           break;
         }
         if (!us->histline) {
-          wbell();
+          mc_wbell();
           werror(_("History buffer empty!"));
           break;
         }
@@ -513,26 +521,26 @@ static void scrollback(void)
         /* open up new search window... */
         searchhist(b_us, look_for);
         /* must redraw status line... */
-        wlocate(b_st, 0, 0); /* move back to column 0! */
-        wprintf(b_st, hline); /* and show the above-defined hline */
-        wredraw(b_st, 1); /* again... */
+        mc_wlocate(b_st, 0, 0); /* move back to column 0! */
+        mc_wprintf(b_st, hline); /* and show the above-defined hline */
+        mc_wredraw(b_st, 1); /* again... */
         /* highlight any matches */
         if (wcslen(look_for) > 1) {
           hit = find_next(us, b_us, y, look_for, case_matters);
 
           if (hit == -1) {
-            wbell();
-            wflush();
+            mc_wbell();
+            mc_wflush();
             hit = 0;
             break;
           }
           drawhist_look(b_us, hit, 1, look_for, case_matters);
           y = hit;
         } else {
-          wbell();
+          mc_wbell();
           break;
         }
-        wflush();
+        mc_wflush();
         break;
         /*
          * fmg 8/22/97
@@ -549,18 +557,18 @@ static void scrollback(void)
           hit = find_next(us, b_us, y, look_for, case_matters);
 
           if (hit == -1) {
-            wbell();
-            wflush();
+            mc_wbell();
+            mc_wflush();
             hit = 0;
             break;
           }
           drawhist_look(b_us, hit, 1, look_for, case_matters);
           y = hit;
         } else	{ /* no search pattern... */
-          wbell();
+          mc_wbell();
           werror(_("No previous search!\n  Please 's' or 'S' first!"));
         }
-        wflush();
+        mc_wflush();
         break;
 
       case 'u':
@@ -573,7 +581,7 @@ static void scrollback(void)
             drawcite(b_us, cite_y+1, y, cite_ystart, cite_yend);
             drawcite(b_us, cite_y, y, cite_ystart, cite_yend);
           }
-          wlocate(b_us, 0, cite_y);
+          mc_wlocate(b_us, 0, cite_y);
           break;
         }
         if (y <= 0)
@@ -581,7 +589,7 @@ static void scrollback(void)
         y--;
         if (cite_ystart != 1000000)
           cite_yend = y + cite_y;
-        wscroll(b_us, S_DOWN);
+        mc_wscroll(b_us, S_DOWN);
 
         /*
          * fmg 8/20/97
@@ -595,7 +603,7 @@ static void scrollback(void)
           tmp_e = getline(b_us, y);
           if (wcslen(look_for) > 1) {
             /* quick scan for pattern match */
-            wdrawelm_var(b_us, tmp_e, tmp_line);
+            mc_wdrawelm_var(b_us, tmp_e, tmp_line);
             inverse = (wcslen(tmp_line)>1 &&
                          StrStr(tmp_line, look_for, case_matters));
           } else
@@ -603,12 +611,12 @@ static void scrollback(void)
         }
 
         if (inverse)
-          wdrawelm_inverse(b_us, 0, getline(b_us, y));
+          mc_wdrawelm_inverse(b_us, 0, getline(b_us, y));
         else
-          wdrawelm(b_us, 0, getline(b_us, y));
+          mc_wdrawelm(b_us, 0, getline(b_us, y));
         if (citemode)
-          wlocate(b_us, 0, cite_y);
-        wflush();
+          mc_wlocate(b_us, 0, cite_y);
+        mc_wflush();
         break;
       case 'd':
       case 'D':
@@ -620,7 +628,7 @@ static void scrollback(void)
             drawcite(b_us, cite_y-1, y, cite_ystart, cite_yend);
             drawcite(b_us, cite_y, y, cite_ystart, cite_yend);
           }
-          wlocate(b_us, 0, cite_y);
+          mc_wlocate(b_us, 0, cite_y);
           break;
         }
 
@@ -629,7 +637,7 @@ static void scrollback(void)
         y++;
         if (cite_ystart != 1000000)
           cite_yend = y + cite_y;
-        wscroll(b_us, S_UP);
+        mc_wscroll(b_us, S_UP);
 
         /*
          * fmg 8/20/97
@@ -643,7 +651,7 @@ static void scrollback(void)
           tmp_e = getline(b_us, y + b_us->ys - 1);
           if (wcslen(look_for) > 1) {
             /* quick scan for pattern match */
-            wdrawelm_var(b_us, tmp_e, tmp_line);
+            mc_wdrawelm_var(b_us, tmp_e, tmp_line);
             inverse = (wcslen(tmp_line)>1 &&
                          StrStr(tmp_line, look_for, case_matters));
           } else
@@ -651,14 +659,14 @@ static void scrollback(void)
         }
 
         if (inverse)
-          wdrawelm_inverse(b_us, b_us->ys - 1,
+          mc_wdrawelm_inverse(b_us, b_us->ys - 1,
                            getline(b_us, y + b_us->ys - 1));
         else
-          wdrawelm(b_us, b_us->ys - 1,
+          mc_wdrawelm(b_us, b_us->ys - 1,
                    getline(b_us, y + b_us->ys - 1));
         if (citemode)
-          wlocate(b_us, 0, cite_y);
-        wflush();
+          mc_wlocate(b_us, 0, cite_y);
+        mc_wflush();
         break;
       case 'b':
       case 'B':
@@ -683,7 +691,7 @@ static void scrollback(void)
           drawhist(b_us, y, 1);
 
         if (citemode)
-          wlocate(b_us, 0, cite_y);
+          mc_wlocate(b_us, 0, cite_y);
         break;
       case 'f':
       case 'F':
@@ -708,7 +716,7 @@ static void scrollback(void)
         else
           drawhist(b_us, y, 1);
         if (citemode)
-          wlocate(b_us, 0, cite_y);
+          mc_wlocate(b_us, 0, cite_y);
         break;
       case 'C': case 'c': /* start citation mode */
         if (citemode ^= 1) {
@@ -722,11 +730,11 @@ static void scrollback(void)
         } else {
           hline = hline0;
         }
-        wlocate(b_st, 0, 0);
-        wprintf(b_st, hline);
-        wredraw(b_st, 1);
+        mc_wlocate(b_st, 0, 0);
+        mc_wprintf(b_st, hline);
+        mc_wredraw(b_st, 1);
         if (citemode)
-          wlocate(b_us, 0, cite_y);
+          mc_wlocate(b_us, 0, cite_y);
         break;
       case 10: case 13:
         if (!citemode) break;
@@ -742,11 +750,11 @@ static void scrollback(void)
           loop = 0;
           break;
         }
-        wlocate(b_st, 0, 0);
-        wprintf(b_st, hline);
-        wredraw(b_st, 1);
-        wdrawelm_inverse(b_us, cite_y, getline(b_us, cite_ystart));
-        wlocate(b_us, 0, cite_y);
+        mc_wlocate(b_st, 0, 0);
+        mc_wprintf(b_st, hline);
+        mc_wredraw(b_st, 1);
+        mc_wdrawelm_inverse(b_us, cite_y, getline(b_us, cite_ystart));
+        mc_wlocate(b_us, 0, cite_y);
         break;
       case K_ESC:
         if (!citemode) {
@@ -761,22 +769,22 @@ static void scrollback(void)
           strcpy(hline1, _("  CITATION: ENTER=select start line ESC=exit                               "));
         }
         drawcite_whole(b_us, y, cite_ystart, cite_yend);
-        wlocate(b_st, 0, 0);
-        wprintf(b_st, hline);
-        wredraw(b_st, 1);
+        mc_wlocate(b_st, 0, 0);
+        mc_wprintf(b_st, hline);
+        mc_wredraw(b_st, 1);
         if (citemode)
-          wlocate(b_us, 0, cite_y);
+          mc_wlocate(b_us, 0, cite_y);
         break;
     }
   }
   /* Cleanup. */
   if (citemode)
     do_cite(b_us, cite_ystart, cite_yend);
-  wclose(b_us, y == us->histlines ? 0 : 1);
-  wclose(b_st, 1);
-  wlocate(us, us->curx, us->cury);
-  wflush();
-  wredraw(us, 1);
+  mc_wclose(b_us, y == us->histlines ? 0 : 1);
+  mc_wclose(b_st, 1);
+  mc_wlocate(us, us->curx, us->cury);
+  mc_wflush();
+  mc_wredraw(us, 1);
 }
 
 #ifdef SIGWINCH
@@ -868,14 +876,14 @@ static void helpthem(void)
 void toggle_addlf(void)
 {
   addlf = !addlf;
-  vt_set(addlf, -1, NULL, -1, -1, -1, -1, -1);
+  vt_set(addlf, -1, -1, -1, -1, -1, -1);
 }
 
 /* Toggle local echo.  Can be called through the menu, or by a macro. */
 void toggle_local_echo(void)
 {
   local_echo = !local_echo;
-  vt_set(-1, -1, NULL, -1, -1, local_echo, -1 ,-1);
+  vt_set(-1, -1, -1, -1, local_echo, -1 ,-1);
 }
 
 int main(int argc, char **argv)
@@ -1130,7 +1138,7 @@ int main(int argc, char **argv)
             exit(1);
           }
           docap = 1;
-          vt_set(addlf, -1, capfp, docap, -1, -1, -1, -1);
+          vt_set(addlf, -1, docap, -1, -1, -1, -1);
           break;
         case 'S': /* start Script */
           strncpy(scr_name, optarg, 33);
@@ -1161,7 +1169,7 @@ int main(int argc, char **argv)
 
   if (screen_iso && screen_ibmpc)
     /* init VT */
-    vt_set(-1, -1, (FILE*)NULL, -1, -1, -1, -1, 1);
+    vt_set(-1, -1, -1, -1, -1, -1, 1);
 
 
 
@@ -1252,14 +1260,14 @@ int main(int argc, char **argv)
 
   if (dial_tty == NULL) {
     if (!dosetup) {
-      while ((dial_tty = get_port(P_PORT)) != NULL && open_term(doinit) < 0)
+      while ((dial_tty = get_port(P_PORT)) != NULL && open_term(doinit, 1) < 0)
         ;
       if (dial_tty == NULL)
         exit(1);
     }
   }
   else {
-    if (!dosetup && open_term(doinit) < 0)
+    if (!dosetup && open_term(doinit, 1) < 0)
       exit(1);
   }
 
@@ -1273,10 +1281,10 @@ int main(int argc, char **argv)
 
   if (dosetup) {
     if (config(1)) {
-      wclose(stdwin, 1);
+      mc_wclose(stdwin, 1);
       exit(0);
     }
-    while ((dial_tty = get_port(P_PORT)) != NULL && open_term(doinit) < 0)
+    while ((dial_tty = get_port(P_PORT)) != NULL && open_term(doinit, 1) < 0)
       ;
     if (dial_tty == NULL)
       exit(1);
@@ -1338,13 +1346,13 @@ int main(int argc, char **argv)
   if (doinit)
     modeminit();
 
-  wprintf(us, "\n%s %s\r\n", _("Welcome to minicom"), VERSION);
-  wprintf(us, "\n%s: %s\r\n", _("OPTIONS"), option_string);
+  mc_wprintf(us, "\n%s %s\r\n", _("Welcome to minicom"), VERSION);
+  mc_wprintf(us, "\n%s: %s\r\n", _("OPTIONS"), option_string);
 #if defined (__DATE__) && defined (__TIME__)
-  wprintf(us, "%s %s, %s.\r\n",_("Compiled on"), __DATE__,__TIME__);
+  mc_wprintf(us, "%s %s, %s.\r\n",_("Compiled on"), __DATE__,__TIME__);
 #endif
-  wprintf(us, "Port %s\n", P_PORT);
-  wprintf(us, _("\nPress %sZ for help on special keys%c\n\n"),esc_key(),'\r');
+  mc_wprintf(us, "Port %s\n", P_PORT);
+  mc_wprintf(us, _("\nPress %sZ for help on special keys%c\n\n"),esc_key(),'\r');
 
   /* Now that all initialization is done, drop our priviliges. */
   drop_privs();
@@ -1378,7 +1386,7 @@ dirty_goto:
           goto dirty_goto;
         break;
       case 'c': /* Clear screen */
-        winclr(us);
+        mc_winclr(us);
         break;
       case 'f': /* Send break */
         sendbreak();
@@ -1455,7 +1463,7 @@ dirty_goto:
           if (c == 1)
             docap = 0;
         }
-        vt_set(addlf, -1, capfp, docap, -1, -1, -1, -1);
+        vt_set(addlf, -1, docap, -1, -1, -1, -1);
         break;
       case 'p': /* Set parameters */
         get_bbp(P_BAUDRATE, P_BITS, P_PARITY, P_STOPB, 0);
@@ -1480,7 +1488,7 @@ dirty_goto:
         break;
       case 'w': /* Line wrap on-off */
         c = (!us->wrap);
-        vt_set(addlf, c, capfp, docap, -1, -1, -1, -1);
+        vt_set(addlf, c, docap, -1, -1, -1, -1);
         s = c ? _("Linewrap ON") : _("Linewrap OFF");
         werror("%s", s);
         break;
@@ -1521,11 +1529,19 @@ dirty_goto:
       do_log("%s", _("Quit without reset while online."));
     m_hupcl(portfd, 0);
   }
+
+  signal(SIGTERM, SIG_IGN);
+  signal(SIGHUP, SIG_IGN);
+#ifdef SIGTSTP
+  signal(SIGTSTP, SIG_DFL);
+#endif
+  signal(SIGQUIT, SIG_DFL);
+
   if (capfp != (FILE *)0)
     fclose(capfp);
-  wclose(us, 0);
-  wclose(st, 0);
-  wclose(stdwin, 1);
+  mc_wclose(us, 0);
+  mc_wclose(st, 0);
+  mc_wclose(stdwin, 1);
   set_privs();
   keyboard(KUNINSTALL, 0);
   if (lockfile[0])
