@@ -1,7 +1,7 @@
 /*
  * minicom.h	Constants, defaults, globals etc.
  *
- *		$Id: minicom.h,v 1.17 2005/10/31 11:10:57 al-guest Exp $
+ *		$Id: minicom.h,v 1.22 2008-02-02 22:49:53 al-guest Exp $
  *
  *		This file is part of the minicom communications package,
  *		Copyright 1991-1995 Miquel van Smoorenburg.
@@ -11,6 +11,10 @@
  *		as published by the Free Software Foundation; either version
  *		2 of the License, or (at your option) any later version.
  *
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
  * fmg 1/11/94 colors
  * fmg 8/22/97 History Buffer Search support
  * jl  23.06.97 sec parameter to m_dtrtoggle
@@ -29,6 +33,8 @@
 #include "vt100.h"
 #include "libport.h"
 
+#include <time.h>
+
 #ifdef USE_SOCKET
 #include <sys/socket.h>
 #include <sys/un.h>
@@ -156,7 +162,7 @@ int  waccess(char *s);
 int  config(int setup);
 void get_bbp(char *ba, char *bi, char *pa, char *stopb, int curr_ok);
 int update_bbp_from_char(char c, char *ba, char *bi, char *pa, char *stopb,
-                         int curr_ok, int max_speed);
+                         int curr_ok);
 const char *yesno(int k);
 int  dotermmenu(void);
 int  dodflsave(void);	/* fmg - need it */
@@ -209,11 +215,11 @@ int main(int argc, char **argv);
 
 /* Prototypes from file: main.c */
 extern time_t old_online;
-void leave(const char *s);
+void leave(const char *s) __attribute__((noreturn));
 char *esc_key(void);
 void term_socket_connect(void);
 void term_socket_close(void);
-int  open_term(int doinit);
+int  open_term(int doinit, int show_win_on_error);
 void init_emul(int type, int do_init);
 void timer_update(void);
 void mode_status(void);
@@ -260,7 +266,7 @@ void m_nohang(int fd);
 void m_hupcl(int fd, int on);
 void m_flush(int fd);
 void m_flush_script( int fd);
-int  m_getmaxspd(void);
+unsigned m_getmaxspd(void);
 void m_setparms(int fd, char *baudr, char *par, char *bits,
                 char *stopb, int hwf, int swf);
 int  m_wait(int *st);
