@@ -4,7 +4,7 @@
  *		not application dependant. It maybe a bit of overhead
  *		but simplifies porting greatly.
  *
- *		$Id: port.h,v 1.5 2005/10/31 10:31:38 al-guest Exp $
+ *		$Id: port.h,v 1.7 2007-10-10 20:18:20 al-guest Exp $
  *
  *		This file is part of the minicom communications package,
  *		Copyright 1991-1995 Miquel van Smoorenburg.
@@ -13,6 +13,10 @@
  *		modify it under the terms of the GNU General Public License
  *		as published by the Free Software Foundation; either version
  *		2 of the License, or (at your option) any later version.
+ *
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 #ifdef ISC
 #  include <sys/bsdtypes.h>
@@ -27,12 +31,14 @@
 #else
    char *getenv(void);
 #endif
+
 #ifdef HAVE_TERMCAP_H
 #  include <termcap.h>
-#else
-  char *tgetstr(void), *tgoto(void);
-  int tgetent(void), tputs(void), tgetnum(void), tgetflag(void);
 #endif
+#ifdef HAVE_NCURSES_TERMCAP_H
+#  include <ncurses/termcap.h>
+#endif
+
 #ifdef _UWIN2P0
 # include <time.h>
 # define MAXNAMLEN 80
