@@ -9,6 +9,10 @@
  *		as published by the Free Software Foundation; either version
  *		2 of the License, or (at your option) any later version.
  *
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
  *	When adding options, remember to add them here in the mpars structure
  *	AND to the macro definitions in configsym.h.
  *
@@ -35,7 +39,7 @@
 #endif
 
 #include "rcsid.h"
-RCSID("$Id: rwconf.c,v 1.11 2006/04/02 09:52:30 al-guest Exp $")
+RCSID("$Id: rwconf.c,v 1.12 2007-10-10 20:18:20 al-guest Exp $")
 
 #include "port.h"
 #include "minicom.h"
