@@ -17,6 +17,10 @@
  *		as published by the Free Software Foundation; either version
  *		2 of the License, or (at your option) any later version.
  *
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
  * 10.07.98 jl  Added the log command
  * 05.04.99 jl  The logfile name should also be passed as a parameter
  * 04.03.2002 jl Treat the ^ character between quotes as control code prefix
@@ -29,7 +33,7 @@
 #include <stdarg.h>
 
 #include "rcsid.h"
-RCSID(PKG_VER "$Id: script.c,v 1.13 2005/08/04 20:33:34 al-guest Exp $")
+RCSID(PKG_VER "$Id: script.c,v 1.14 2007-10-10 20:18:20 al-guest Exp $")
 
 #include "port.h"
 #include "minicom.h"
