@@ -5,7 +5,7 @@
  *		included. This file is only included from sysdep[12].c
  *		anyway!
  *
- *		$Id: sysdep.h,v 1.3 2003/04/19 16:17:33 al-guest Exp $
+ *		$Id: sysdep.h,v 1.4 2007-10-10 20:18:20 al-guest Exp $
  *
  *		This file is part of the minicom communications package,
  *		Copyright 1991-1995 Miquel van Smoorenburg.
@@ -14,6 +14,10 @@
  *		modify it under the terms of the GNU General Public License
  *		as published by the Free Software Foundation; either version
  *		2 of the License, or (at your option) any later version.
+ *
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 #ifdef HAVE_FEATURES_H
 #include <features.h>
