@@ -23,6 +23,10 @@
  *		as published by the Free Software Foundation; either version
  *		2 of the License, or (at your option) any later version.
  *
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
  *   jl  23.06.97  adjustable DTR downtime
  */
 #ifdef HAVE_CONFIG_H
@@ -30,7 +34,7 @@
 #endif
 
 #include "rcsid.h"
-RCSID("$Id: sysdep1.c,v 1.5 2005/08/04 20:33:34 al-guest Exp $")
+RCSID("$Id: sysdep1.c,v 1.8 2007-10-10 20:18:20 al-guest Exp $")
 
 #include "sysdep.h"
 #include "minicom.h"
@@ -211,9 +215,10 @@ int m_getdcd(int fd)
 #endif
 #ifdef TIOCMODG
   {
-    int mcs=0;
+    int mcs = 0;
 
-    ioctl(fd, TIOCMODG, &mcs);
+    if (ioctl(fd, TIOCMODG, &mcs) < 0)
+      return -1;
     return mcs & TIOCM_CAR ? 1 : 0;
   }
 #else
@@ -372,26 +377,50 @@ int m_readchk(int fd)
 
 /*
  * Get maximum speed.
- * Returns maximum speed / 100. (192-1152)
+ * Returns maximum speed in baud
  */
-int m_getmaxspd(void)
+unsigned m_getmaxspd(void)
 {
-#ifdef B230400
-  return 2304;
+#if defined(B4000000)
+  return 4000000;
+#elif defined(B3500000)
+  return 3500000;
+#elif defined(B3000000)
+  return 3000000;
+#elif defined(B2500000)
+  return 2500000;
+#elif defined(B2000000)
+  return 2000000;
+#elif defined(B1500000)
+  return 1500000;
+#elif defined(B1152000)
+  return 1152000;
+#elif defined(B1000000)
+  return 1000000;
+#elif defined(B921600)
+  return 921600;
+#elif defined(B576000)
+  return 576000;
+#elif defined(B500000)
+  return 500000;
+#elif defined(B460800)
+  return 460800;
+#elif defined(B230400)
+  return 230400;
 #elif defined(B115200)
-  return 1152;
+  return 115200;
 #elif defined(B57600)
-  return 576;
+  return 57600;
 #elif defined(B38400)
-  return 384;
+  return 38400;
 #elif defined(EXTB)
-  return 384;
+  return 38400;
 #elif defined(B19200)
-  return 192;
+  return 19200;
 #elif defined(EXTA)
-  return 192;
+  return 19200;
 #else
-  return 96;
+  return 9600;
 #endif
 }
 
@@ -471,6 +500,42 @@ void m_setparms(int fd, char *baudr, char *par, char *bits, char *stopb,
 #endif
 #ifdef B230400
     case 2304:	spd = B230400;	break;
+#endif
+#ifdef B460800
+    case 4608: spd = B460800; break;
+#endif
+#ifdef B500000
+    case 5000: spd = B500000; break;
+#endif
+#ifdef B576000
+    case 5760: spd = B576000; break;
+#endif
+#ifdef B921600
+    case 9216: spd = B921600; break;
+#endif
+#ifdef B1000000
+    case 10000: spd = B1000000; break;
+#endif
+#ifdef B1152000
+    case 11520: spd = B1152000; break;
+#endif
+#ifdef B1500000
+    case 15000: spd = B1500000; break;
+#endif
+#ifdef B2000000
+    case 20000: spd = B2000000; break;
+#endif
+#ifdef B2500000
+    case 25000: spd = B2500000; break;
+#endif
+#ifdef B3000000
+    case 30000: spd = B3000000; break;
+#endif
+#ifdef B3500000
+    case 35000: spd = B3500000; break;
+#endif
+#ifdef B4000000
+    case 40000: spd = B4000000; break;
 #endif
   }
 
