@@ -15,13 +15,17 @@
  *		modify it under the terms of the GNU General Public License
  *		as published by the Free Software Foundation; either version
  *		2 of the License, or (at your option) any later version.
+ *
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
 #include "rcsid.h"
-RCSID("$Id: sysdep1_s.c,v 1.2 2003/07/26 15:51:13 al-guest Exp $")
+RCSID("$Id: sysdep1_s.c,v 1.3 2007-10-10 20:18:20 al-guest Exp $")
 
 #include "sysdep.h"
 #include "minicom.h"
