@@ -10,6 +10,10 @@
  *		as published by the Free Software Foundation; either version
  *		2 of the License, or (at your option) any later version.
  *
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
  * jl 13.09.97	pass actual terminal lines (LINES - statusline)
  *		to runscript in environment variable TERMLIN
  * jl 16.09.97	logging of sz/rz file transfers
@@ -23,7 +27,7 @@
 #endif
 
 #include "rcsid.h"
-RCSID("$Id: updown.c,v 1.7 2005/08/14 20:39:30 al-guest Exp $")
+RCSID("$Id: updown.c,v 1.9 2007-10-10 20:18:20 al-guest Exp $")
 
 #include "port.h"
 #include "minicom.h"
@@ -199,7 +203,7 @@ void updown(int what, int nr)
     if (g == 0)
       return;
 
-    r = wselect(30, 7, name, NULL, t, stdattr, mfcolor, mbcolor) - 1;
+    r = mc_wselect(30, 7, name, NULL, t, stdattr, mfcolor, mbcolor) - 1;
     if (r < 0)
       return;
 
@@ -240,13 +244,13 @@ void updown(int what, int nr)
     do_log("%s", cmdline);   /* jl 22.06.97 */
 
   if (P_PFULL(g) == 'N') {
-    win = wopen(10, 7, 70, 13, BSINGLE, stdattr, mfcolor, mbcolor, 1, 0, 1);
+    win = mc_wopen(10, 7, 70, 13, BSINGLE, stdattr, mfcolor, mbcolor, 1, 0, 1);
     snprintf(title, sizeof(title), _("%.30s %s - Press CTRL-C to quit"), P_PNAME(g),
              what == 'U' ? _("upload") : _("download"));
-    wtitle(win, TMID, title);
+    mc_wtitle(win, TMID, title);
     pipe(pipefd);
   } else
-    wleave();
+    mc_wleave();
 
   switch (udpid = fork()) {
     case -1:
@@ -254,9 +258,9 @@ void updown(int what, int nr)
       if (win) {
         close(pipefd[0]);
         close(pipefd[1]);
-        wclose(win, 1);
+        mc_wclose(win, 1);
       } else
-        wreturn();
+        mc_wreturn();
       mcd("");
       return;
     case 0: /* Child */
@@ -293,7 +297,7 @@ void updown(int what, int nr)
 #endif
     while ((n = read(pipefd[0], buf, sizeof(buf))) > 0) {
       buf[n] = '\0';
-      wputs(win, buf);
+      mc_wputs(win, buf);
       timer_update();
       /* Log the filenames & sizes 	jl 14.09.97 */
       if (P_LOGXFER[0] == 'Y') {
@@ -338,7 +342,7 @@ void updown(int what, int nr)
   }
 
   if (win == (WIN *)0)
-    wreturn();
+    mc_wreturn();
 
   /* MARK updated 02/17/94 - Flush modem port before displaying READY msg */
   /* because a BBS often displays menu text right after a download, and we */
@@ -355,7 +359,7 @@ void updown(int what, int nr)
   if (win && (status & 0xFF00) == 0) {
 #if VC_MUSIC
     if (P_SOUND[0] == 'Y') {
-      wprintf(win, _("\n READY: press any key to continue..."));
+      mc_wprintf(win, _("\n READY: press any key to continue..."));
       music();
     } else
       sleep(1);
@@ -363,12 +367,12 @@ void updown(int what, int nr)
     /* MARK updated 02/17/94 - If there was no VC_MUSIC capability, */
     /* then at least make some beeps! */
     if (P_SOUND[0] == 'Y')
-      wprintf(win, "\007\007\007");
+      mc_wprintf(win, "\007\007\007");
     sleep(1);
 #endif
   }
   if (win)
-    wclose(win, 1);
+    mc_wclose(win, 1);
 }
 
 /*
@@ -384,11 +388,11 @@ void kermit(void)
   int fd;
 
   /* Clear screen, set keyboard modes etc. */
-  wleave();
+  mc_wleave();
 
   switch (pid = fork()) {
     case -1:
-      wreturn();
+      mc_wreturn();
       werror(_("Out of memory: could not fork()"));
       return;
     case 0: /* Child */
@@ -411,7 +415,7 @@ void kermit(void)
   m_wait(&status);
 
   /* Restore screen and keyboard modes */
-  wreturn();
+  mc_wreturn();
 
   /* Re-create lockfile */
   if (lockfile[0]) {
@@ -523,18 +527,18 @@ void runscript(int ask, const char *s, const char *l, const char *p)
 
 
   if (ask) {
-    w = wopen(10, 5, 70, 10, BDOUBLE, stdattr, mfcolor, mbcolor, 0, 0, 1);
-    wtitle(w, TMID, _("Run a script"));
-    wputs(w, "\n");
-    wprintf(w, "%s %s\n", username, scr_user[0] ? msg : "");
-    wprintf(w, "%s %s\n", password, scr_passwd[0] ? msg : "");
-    wprintf(w, "%s %s\n", name_of_script, scr_name);
-    wlocate(w, 4, 5);
-    wputs(w, question);
-    wredraw(w, 1);
+    w = mc_wopen(10, 5, 70, 10, BDOUBLE, stdattr, mfcolor, mbcolor, 0, 0, 1);
+    mc_wtitle(w, TMID, _("Run a script"));
+    mc_wputs(w, "\n");
+    mc_wprintf(w, "%s %s\n", username, scr_user[0] ? msg : "");
+    mc_wprintf(w, "%s %s\n", password, scr_passwd[0] ? msg : "");
+    mc_wprintf(w, "%s %s\n", name_of_script, scr_name);
+    mc_wlocate(w, 4, 5);
+    mc_wputs(w, question);
+    mc_wredraw(w, 1);
 
     while (!done) {
-      wlocate(w, mbslen (question) + 5, 5);
+      mc_wlocate(w, mbslen (question) + 5, 5);
       n = wxgetch();
       if (islower(n))
         n = toupper(n);
@@ -542,30 +546,30 @@ void runscript(int ask, const char *s, const char *l, const char *p)
         case '\r':
         case '\n':
           if (scr_name[0] == '\0') {
-            wbell();
+            mc_wbell();
             break;
           }
-          wclose(w, 1);
+          mc_wclose(w, 1);
           done = 1;
           break;
         case 27: /* ESC */
-          wclose(w, 1);
+          mc_wclose(w, 1);
           return;
         case 'A':
-          wlocate(w, mbslen (username) + 1, 1);
-          wclreol(w);
+          mc_wlocate(w, mbslen (username) + 1, 1);
+          mc_wclreol(w);
           scr_user[0] = 0;
-          wgets(w, scr_user, 32, 32);
+          mc_wgets(w, scr_user, 32, 32);
           break;
         case 'B':
-          wlocate(w, mbslen (password) + 1, 2);
-          wclreol(w);
+          mc_wlocate(w, mbslen (password) + 1, 2);
+          mc_wclreol(w);
           scr_passwd[0] = 0;
-          wgets(w, scr_passwd, 32, 32);
+          mc_wgets(w, scr_passwd, 32, 32);
           break;
         case 'C':
-          wlocate(w, mbslen (name_of_script) + 1, 3);
-          wgets(w, scr_name, 32, 32);
+          mc_wlocate(w, mbslen (name_of_script) + 1, 3);
+          mc_wgets(w, scr_name, 32, 32);
           break;
         default:
           break;
@@ -580,7 +584,7 @@ void runscript(int ask, const char *s, const char *l, const char *p)
 
   /* Throw away status line if temporary */
   if (tempst) {
-    wclose(st, 1);
+    mc_wclose(st, 1);
     tempst = 0;
     st = NULL;
   }
@@ -633,7 +637,7 @@ void runscript(int ask, const char *s, const char *l, const char *p)
     while (n--)
       vt_out(*ptr++);
     timer_update();
-    wflush();
+    mc_wflush();
   }
   
   /* Collect status, and clean up. */
@@ -687,7 +691,7 @@ int paste_file(void)
 	  *ptr &= 0x7f;
 	vt_out(*ptr++);
       }
-      wflush();
+      mc_wflush();
     }
 
     if (dotrans && (s = strrchr(line, '\n')) != NULL) {
