@@ -9,6 +9,10 @@
  *		as published by the Free Software Foundation; either version
  *		2 of the License, or (at your option) any later version.
  *
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
  * jseymour@jimsun.LinxNet.com (Jim Seymour) 03/26/98 - Added get_port()
  *    function to support multiple port specifications in config.
  */
@@ -17,7 +21,7 @@
 #endif
 
 #include "rcsid.h"
-RCSID("$Id: util.c,v 1.7 2005/11/08 23:34:25 al-guest Exp $")
+RCSID("$Id: util.c,v 1.8 2007-10-10 20:18:20 al-guest Exp $")
 
 #include "port.h"
 #include "minicom.h"
