@@ -15,6 +15,10 @@
  *		as published by the Free Software Foundation; either version
  *		2 of the License, or (at your option) any later version.
  *
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
  * // jl 04.09.97 character map conversions in and out
  *    jl 06.07.98 use conversion tables with the capture file
  */
@@ -23,7 +27,7 @@
 #endif
 
 #include "rcsid.h"
-RCSID("$Id: vt100.c,v 1.10 2006/04/02 09:52:30 al-guest Exp $")
+RCSID("$Id: vt100.c,v 1.14 2007-10-10 20:18:20 al-guest Exp $")
 
 #include "port.h"
 #include "minicom.h"
@@ -122,9 +126,8 @@ unsigned char vt_outmap[256] = {
 
 #if TRANSLATE
 /* Taken from the Linux kernel source: linux/drivers/char/console.c */
-static unsigned char * vt_map[] = {
+static char * vt_map[] = {
 /* 8-bit Latin-1 mapped to the PC character set: '.' means non-printable */
-(unsigned char *)
   "................"
   "................"
   " !\"#$%&'()*+,-./0123456789:;<=>?"
@@ -139,7 +142,6 @@ static unsigned char * vt_map[] = {
   "\205\240\203\376\204\206\221\207\212\202\210\211\215\241\214\213"
   "\376\244\225\242\223\376\224\366\355\227\243\226\201\376\376\230",
 /* vt100 graphics */
-(unsigned char *)
   "................"
   "\0\0\0\0\0\0\0\0\0\0\376\0\0\0\0\0"
   " !\"#$%&'()*+,-./0123456789:;<=>?"
@@ -175,7 +177,6 @@ static int vt_crlf = 0;		/* Return sends CR/LF */
 static int vt_om;		/* Origin mode. */
 WIN *vt_win          = NULL;	/* Output window. */
 static int vt_docap;		/* Capture on/off. */
-static FILE *vt_capfp;		/* Capture file. */
 static void (*vt_keyb)(int, int);/* Gets called for NORMAL/APPL switch. */
 static void (*termout)(const char *, int);/* Gets called to output a string. */
 
@@ -215,13 +216,13 @@ void vt_pinit(WIN *win, int fg, int bg)
   vt_win = win;
   newy1 = 0;
   newy2 = vt_win->ys - 1;
-  wresetregion(vt_win);
+  mc_wresetregion(vt_win);
   if (fg > 0)
     vt_fg = fg;
   if (bg > 0)
     vt_bg = bg;
-  wsetfgcol(vt_win, vt_fg);
-  wsetbgcol(vt_win, vt_bg);
+  mc_wsetfgcol(vt_win, vt_fg);
+  mc_wsetbgcol(vt_win, vt_bg);
 }
 
 /* Set characteristics of emulator. */
@@ -244,7 +245,7 @@ void vt_init(int type, int fg, int bg, int wrap, int add)
 
   newy1 = 0;
   newy2 = vt_win->ys - 1;
-  wresetregion(vt_win);
+  mc_wresetregion(vt_win);
   vt_keypad = NORMAL;
   vt_cursor = NORMAL;
   vt_echo = 0;
@@ -268,20 +269,18 @@ void vt_init(int type, int fg, int bg, int wrap, int add)
 
   if (vt_keyb)
     (*vt_keyb)(vt_keypad, vt_cursor);
-  wsetfgcol(vt_win, vt_fg);
-  wsetbgcol(vt_win, vt_bg);
+  mc_wsetfgcol(vt_win, vt_fg);
+  mc_wsetbgcol(vt_win, vt_bg);
 }
 
 /* Change some things on the fly. */
-void vt_set(int addlf, int wrap, FILE *capfp, int docap, int bscode,
+void vt_set(int addlf, int wrap, int docap, int bscode,
             int echo, int cursor, int asis)
 {
   if (addlf >= 0)
     vt_addlf = addlf;
   if (wrap >= 0)
     vt_win->wrap = vt_wrap = wrap;
-  if (capfp != NULL)
-    vt_capfp = capfp;
   if (docap >= 0)
     vt_docap = docap;
   if (bscode >= 0)
@@ -305,7 +304,7 @@ static void v_termout(const char *s, int len)
       if (!vt_addlf && *p == '\r')
         vt_out('\n');
     }
-    wflush();
+    mc_wflush();
   }
 
   (*termout)(s, len);
@@ -344,20 +343,20 @@ static void state1(int c)
       if (c == 'D') { /* Down. */
         y = vt_win->cury + 1;
         if (y == newy2 + 1)
-          wscroll(vt_win, S_UP);
+          mc_wscroll(vt_win, S_UP);
         else if (vt_win->cury < vt_win->ys)
-          wlocate(vt_win, x, y);
+          mc_wlocate(vt_win, x, y);
       }
       if (c == 'M')  { /* Up. */
         y = vt_win->cury - 1;
         if (y == newy1 - 1)
-          wscroll(vt_win, S_DOWN);
+          mc_wscroll(vt_win, S_DOWN);
         else if (y >= 0)
-          wlocate(vt_win, x, y);
+          mc_wlocate(vt_win, x, y);
       }
       break;
     case 'E': /* CR + NL */
-      wputs(vt_win, "\r\n");
+      mc_wputs(vt_win, "\r\n");
       break;
     case '7': /* Save attributes and cursor position */
     case 's':
@@ -378,9 +377,9 @@ static void state1(int c)
       vt_trans[0] = savetrans[0];
       vt_trans[1] = savetrans[1];
 #endif
-      vt_win->color = savecol; /* HACK should use wsetfgcol etc */
-      wsetattr(vt_win, saveattr);
-      wlocate(vt_win, savex, savey);
+      vt_win->color = savecol; /* HACK should use mc_wsetfgcol etc */
+      mc_wsetattr(vt_win, saveattr);
+      mc_wlocate(vt_win, savex, savey);
       break;
     case '=': /* Keypad into applications mode */
       vt_keypad = APPL;
@@ -400,13 +399,13 @@ static void state1(int c)
       break;
     case 'c': /* Reset to initial state */
       f = XA_NORMAL;
-      wsetattr(vt_win, f);
+      mc_wsetattr(vt_win, f);
       vt_win->wrap = (vt_type != VT100);
       if (vt_wrap != -1)
         vt_win->wrap = vt_wrap;
       vt_crlf = vt_insert = 0;
       vt_init(vt_type, vt_fg, vt_bg, vt_win->wrap, 0);
-      wlocate(vt_win, 0, 0);
+      mc_wlocate(vt_win, 0, 0);
       break;
     case 'H': /* Set tab in current position */
       x = vt_win->curx;
@@ -511,23 +510,23 @@ static void state2(int c)
         if (y <= newy1 - 1)
           y = newy1;
       }	
-      wlocate(vt_win, x, y);
+      mc_wlocate(vt_win, x, y);
       break;
     case 'X': /* Character erasing (ECH) */
       if ((f = escparms[0]) == 0)
         f = 1;
-      wclrch(vt_win, f);
+      mc_wclrch(vt_win, f);
       break;
     case 'K': /* Line erasing */
       switch (escparms[0]) {
         case 0:
-          wclreol(vt_win);
+          mc_wclreol(vt_win);
           break;
         case 1:
-          wclrbol(vt_win);
+          mc_wclrbol(vt_win);
           break;
         case 2:
-          wclrel(vt_win);
+          mc_wclrel(vt_win);
           break;
       }
       break;
@@ -535,19 +534,19 @@ static void state2(int c)
       x = vt_win->color;
       y = vt_win->attr;
       if (vt_type == ANSI) {
-        wsetattr(vt_win, XA_NORMAL);
-        wsetfgcol(vt_win, WHITE);
-        wsetbgcol(vt_win, BLACK);
+        mc_wsetattr(vt_win, XA_NORMAL);
+        mc_wsetfgcol(vt_win, WHITE);
+        mc_wsetbgcol(vt_win, BLACK);
       }
       switch (escparms[0]) {
         case 0:
-          wclreos(vt_win);
+          mc_wclreos(vt_win);
           break;
         case 1:
-          wclrbos(vt_win);
+          mc_wclrbos(vt_win);
           break;
         case 2:
-          winclr(vt_win);
+          mc_winclr(vt_win);
           break;
       }
       if (vt_type == ANSI) {
@@ -596,9 +595,9 @@ static void state2(int c)
       vt_trans[1] = savetrans[1];
 #endif
       break;
-      vt_win->color = savecol; /* HACK should use wsetfgcol etc */
-      wsetattr(vt_win, saveattr);
-      wlocate(vt_win, savex, savey);
+      vt_win->color = savecol; /* HACK should use mc_wsetfgcol etc */
+      mc_wsetattr(vt_win, saveattr);
+      mc_wlocate(vt_win, savex, savey);
       break;
     case 'h':
       ansi_mode(1);
@@ -614,7 +613,7 @@ static void state2(int c)
         x = 1;
       if (vt_om)
         y += newy1;
-      wlocate(vt_win, x - 1, y - 1);
+      mc_wlocate(vt_win, x - 1, y - 1);
       break;
     case 'g': /* Clear tab stop(s) */
       if (escparms[0] == 0) {
@@ -633,17 +632,17 @@ static void state2(int c)
       if (ptr < 0)
         ptr = 0;
 #endif
-      attr = wgetattr((vt_win));
+      attr = mc_wgetattr((vt_win));
       for (f = 0; f <= ptr; f++) {
         if (escparms[f] >= 30 && escparms[f] <= 37)
-          wsetfgcol(vt_win, escparms[f] - 30);
+          mc_wsetfgcol(vt_win, escparms[f] - 30);
         if (escparms[f] >= 40 && escparms[f] <= 47)
-          wsetbgcol(vt_win, escparms[f] - 40);
+          mc_wsetbgcol(vt_win, escparms[f] - 40);
         switch (escparms[f]) {
           case 0:
             attr = XA_NORMAL;
-            wsetfgcol(vt_win, vt_fg);
-            wsetbgcol(vt_win, vt_bg);
+            mc_wsetfgcol(vt_win, vt_fg);
+            mc_wsetbgcol(vt_win, vt_bg);
             break;
           case 4:
             attr |= XA_UNDERLINE;
@@ -670,38 +669,38 @@ static void state2(int c)
             attr &= ~XA_REVERSE;
             break;
           case 39: /* Default fg color */
-            wsetfgcol(vt_win, vt_fg);
+            mc_wsetfgcol(vt_win, vt_fg);
             break;
           case 49: /* Default bg color */
-            wsetbgcol(vt_win, vt_bg);
+            mc_wsetbgcol(vt_win, vt_bg);
             break;
         }
       }
-      wsetattr(vt_win, attr);
+      mc_wsetattr(vt_win, attr);
       break;
     case 'L': /* Insert lines */
       if ((x = escparms[0]) == 0)
         x = 1;
       for (f = 0; f < x; f++)
-        winsline(vt_win);
+        mc_winsline(vt_win);
       break;
     case 'M': /* Delete lines */
       if ((x = escparms[0]) == 0)
         x = 1;
       for (f = 0; f < x; f++)
-        wdelline(vt_win);
+        mc_wdelline(vt_win);
       break;
     case 'P': /* Delete Characters */
       if ((x = escparms[0]) == 0)
         x = 1;
       for (f = 0; f < x; f++)
-        wdelchar(vt_win);
+        mc_wdelchar(vt_win);
       break;
     case '@': /* Insert Characters */
       if ((x = escparms[0]) == 0)
         x = 1;
       for (f = 0; f < x; f++)
-        winschar(vt_win);
+        mc_winschar(vt_win);
       break;
     case 'r': /* Set scroll region */
       if ((newy1 = escparms[0]) == 0)
@@ -721,8 +720,8 @@ static void state2(int c)
         newy1 = 0;
         newy2 = vt_win->ys - 1;
       }
-      wsetregion(vt_win, newy1, newy2);
-      wlocate(vt_win, 0, newy1);
+      mc_wsetregion(vt_win, newy1, newy2);
+      mc_wlocate(vt_win, 0, newy1);
       break;
     case 'i': /* Printing */
     case 'y': /* Self test modes */
@@ -755,13 +754,13 @@ static void dec_mode(int on_off)
         break;
       case 6: /* Origin mode. */
         vt_om = on_off;
-        wlocate(vt_win, 0, newy1);
+        mc_wlocate(vt_win, 0, newy1);
         break;
       case 7: /* Auto wrap */
         vt_win->wrap = on_off;
         break;
       case 25: /* Cursor on/off */
-        wcursor(vt_win, on_off ? CNORMAL : CNONE);
+        mc_wcursor(vt_win, on_off ? CNORMAL : CNONE);
         break;
       case 67: /* Backspace key sends. (FIXME: vt420) */
         /* setbackspace(on_off ? 8 : 127); */
@@ -878,15 +877,15 @@ static void state6(int c)
       /* Selftest: fill screen with E's */
       vt_win->doscroll = 0;
       vt_win->direct = 0;
-      wlocate(vt_win, 0, 0);
+      mc_wlocate(vt_win, 0, 0);
       for (y = 0; y < vt_win->ys; y++) {
-        wlocate(vt_win, 0, y);
+        mc_wlocate(vt_win, 0, y);
         for (x = 0; x < vt_win->xs; x++)
-          wputc(vt_win, 'E');
+          mc_wputc(vt_win, 'E');
       }
-      wlocate(vt_win, 0, 0);
+      mc_wlocate(vt_win, 0, 0);
       vt_win->doscroll = 1;
-      wredraw(vt_win, 1);
+      mc_wredraw(vt_win, 1);
       break;
     default:
       /* IGNORED */
@@ -922,9 +921,9 @@ static void state7(int c)
       return;
     /* Process string here! */
     if (!strcmp(buf, "cursor.on"))
-      wcursor(vt_win, CNORMAL);
+      mc_wcursor(vt_win, CNORMAL);
     if (!strcmp(buf, "cursor.off"))
-      wcursor(vt_win, CNONE);
+      mc_wcursor(vt_win, CNONE);
     if (!strcmp(buf, "linewrap.on")) {
       vt_wrap = -1;
       vt_win->wrap = 1;
@@ -961,7 +960,7 @@ void vt_out(int ch)
   c = (unsigned char)ch;
 
   if (vt_docap == 2) /* Literal. */
-    fputc(c, vt_capfp);
+    fputc(c, capfp);
 
   /* Process <31 chars first, even in an escape sequence. */
   switch (c) {
@@ -973,11 +972,11 @@ void vt_out(int ch)
       v_termout(P_ANSWERBACK, 0);
       break;
     case '\r': /* Carriage return */
-      wputc(vt_win, c);
+      mc_wputc(vt_win, c);
       if (vt_addlf) {
-        wputc(vt_win, '\n');
+        mc_wputc(vt_win, '\n');
         if (vt_docap == 1)
-          fputc('\n', vt_capfp);
+          fputc('\n', capfp);
       }
       break;
     case '\t': /* Non - destructive TAB */
@@ -987,16 +986,16 @@ void vt_out(int ch)
           break;
       if (f >= vt_win->xs)
         f = vt_win->xs - 1;
-      wlocate(vt_win, f, vt_win->cury);
+      mc_wlocate(vt_win, f, vt_win->cury);
       if (vt_docap == 1)
-        fputc(c, vt_capfp);
+        fputc(c, capfp);
       break;
     case 013: /* Old Minix: CTRL-K = up */
-      wlocate(vt_win, vt_win->curx, vt_win->cury - 1);
+      mc_wlocate(vt_win, vt_win->curx, vt_win->cury - 1);
       break;
     case '\f': /* Form feed: clear screen. */
-      winclr(vt_win);
-      wlocate(vt_win, 0, 0);
+      mc_winclr(vt_win);
+      mc_wlocate(vt_win, 0, 0);
       break;
 #if !TRANSLATE
     case 14:
@@ -1023,9 +1022,9 @@ void vt_out(int ch)
     case '\n':
     case '\b':
     case 7: /* Bell */
-      wputc(vt_win, c);
+      mc_wputc(vt_win, c);
       if (vt_docap == 1)
-        fputc(c, vt_capfp);
+        fputc(c, capfp);
       break;
     default:
       go_on = 1;
@@ -1038,7 +1037,7 @@ void vt_out(int ch)
   switch (esc_s) {
     case 0: /* Normal character */
       if (vt_docap == 1)
-        fputc(P_CONVCAP[0] == 'Y' ? vt_inmap[c] : c, vt_capfp);
+        fputc(P_CONVCAP[0] == 'Y' ? vt_inmap[c] : c, capfp);
       c = vt_inmap[c];    /* conversion 04.09.97 / jl */
 #if TRANSLATE
       if (vt_type == VT100 && vt_asis == 0)
@@ -1049,11 +1048,11 @@ void vt_out(int ch)
        * is 8-bit, the character should not be changed by mapping to
        * wchar and back; if the locale is multibyte, there is no hope
        * of getting it right anyway. */
-      one_mbtowc (&wc, &c, 1); /* returns 1 */
+      one_mbtowc (&wc, (char *)&c, 1); /* returns 1 */
       if (vt_insert)
-        winschar2(vt_win, wc, 1);
+        mc_winschar2(vt_win, wc, 1);
       else
-        wputc(vt_win, wc);
+        mc_wputc(vt_win, wc);
       break;
     case 1: /* ESC seen */
       state1(c);
@@ -1080,8 +1079,8 @@ void vt_out(int ch)
 
   /* Flush output to capture file so that all output is visible there
    * immediately. Causes a write syscall for every call though. */
-  if (vt_capfp)
-    fflush(vt_capfp);
+  if (capfp)
+    fflush(capfp);
 }
 
 /* Translate keycode to escape sequence. */
