@@ -1,5 +1,5 @@
 /*
-**  
+**
 **  Do shell-style pattern matching for ?, \, [], and * characters.
 **  Might not be robust in face of malformed patterns; e.g., "foo[a-"
 **  could cause a segmentation violation.  It is 8bit clean.
@@ -22,7 +22,7 @@
 **  bernie    597-02 91/01/21 13:43
 **	Fixed . matching * or ? on first char.
 **
-**  jseymour  91/02/05 22:56 
+**  jseymour  91/02/05 22:56
 **	Fixed problems with ill-formed sets in pattern yielding false
 **	matches.  Should now be robust in such cases (not all possibilities
 **	tested - standard disclaimer).  Added stand-alone debug code.
@@ -55,9 +55,9 @@
 #endif
 
 #include "rcsid.h"
-RCSID("$Id: wildmat.c,v 1.1.1.1 2003/03/30 18:55:54 al-guest Exp $")
+RCSID("$Id: wildmat.c,v 1.3 2005/08/04 20:33:34 al-guest Exp $")
 
-#include "port.h"	/* from minicom: for needed for _PROTO macro only */
+#include "minicom.h"
 
 #ifndef TRUE
 #define TRUE	 1
@@ -67,94 +67,82 @@ RCSID("$Id: wildmat.c,v 1.1.1.1 2003/03/30 18:55:54 al-guest Exp $")
 #endif
 #define ABORT	-1
 
-_PROTO(static int Star, (char *, char *));
-_PROTO(static int DoMatch, (char *, char *));
-_PROTO(extern int wildmat, (char *, char *));	/* pattern matcher */
+static int Star(const char *, const char *);
+static int DoMatch(const char *, const char *);
 
-static int
-Star(s, p)
-register char *s;
-register char *p;
+static int Star(const char *s, const char *p)
 {
-    int retval;
+  int retval;
 
-    while ((retval = DoMatch(s, p)) == FALSE)	/* gobble up * match */
-	if (*++s == '\0')
-	    return ABORT;
-    return retval;
+  while ((retval = DoMatch(s, p)) == FALSE)	/* gobble up * match */
+    if (*++s == '\0')
+      return ABORT;
+  return retval;
 }
 
-
-static int
-DoMatch(s, p)			/* match string "s" to pattern "p" */
-register char *s;
-register char *p;
+/* match string "s" to pattern "p" */
+static int DoMatch(const char *s, const char *p)
 {
-    register int last;
-    register int matched;
-    register int reverse;
-    char *ss;
-    int escaped;
+  register int last;
+  register int matched;
+  register int reverse;
+  const char *ss;
+  int escaped;
 
-    for (; *p; s++, p++)
-    {				/* parse the string to end */
+  for (; *p; s++, p++) {                        /* parse the string to end */
 
-	if (*s == '\0')
-	    return *p == '*' && *++p == '\0' ? TRUE : ABORT;
+    if (*s == '\0')
+      return *p == '*' && *++p == '\0' ? TRUE : ABORT;
 
-	switch (*p)
-	{			/* parse pattern */
+    switch (*p) {			        /* parse pattern */
 
-	    case '\\':
-		/* Literal match with following character. */
-		p++;
-		/* FALLTHROUGH */
+      case '\\':
+        /* Literal match with following character. */
+        p++;
+        /* FALLTHROUGH */
 
-	    default:		/*literal match*/
-		if (*s != *p)
-		    return FALSE;
-		continue;
+      default:		/*literal match*/
+        if (*s != *p)
+          return FALSE;
+        continue;
 
-	    case '?':
-		/* Match anything. */
-		continue;
+      case '?':
+        /* Match anything. */
+        continue;
 
-	    case '*':
-		/* Trailing star matches everything. */
-		return (*++p ? Star(s, p) : TRUE);
+      case '*':
+        /* Trailing star matches everything. */
+        return *++p ? Star(s, p) : TRUE;
 
-	    case '[':
-		/* [!....] means inverse character class. */
-		if ((reverse = (p[1] == '!')))
-		    p++;
-		ss = p + 1;	/* set start point */
+      case '[':
+        /* [!....] means inverse character class. */
+        if ((reverse = (p[1] == '!')))
+          p++;
+        ss = p + 1;	/* set start point */
 
-		for (last = 0400, escaped = matched = FALSE; *++p; last = *p)
-		{
-		    if (*p == ']' && !(escaped || p == ss))
-			break;
-		    if (escaped)
-			escaped = FALSE;
-		    else if (*p == '\\')
-		    {
-			escaped = TRUE;
-			continue;
-		    }
+        for (last = 0400, escaped = matched = FALSE; *++p; last = *p) {
+          if (*p == ']' && !(escaped || p == ss))
+            break;
+          if (escaped)
+            escaped = FALSE;
+          else if (*p == '\\') {
+            escaped = TRUE;
+            continue;
+          }
 
-		    /* This next line requires a good C compiler.	    */
-		    /*     range?	(in bounds)                 (equal) */
-		    if ((*p == '-') ? (*s <= *++p && *s >= last) : (*s == *p))
-			matched = TRUE;
-		}
+          /* This next line requires a good C compiler.	    */
+          /*     range?	(in bounds)                 (equal) */
+          if ((*p == '-') ? (*s <= *++p && *s >= last) : (*s == *p))
+            matched = TRUE;
+        }
 
-		if (matched == reverse)
-		    return FALSE;
-		continue;
-
-	}
+        if (matched == reverse)
+          return FALSE;
+        continue;
     }
+  }
 
-    return *s == '\0';
+  return *s == '\0';
 }
 
 
@@ -163,19 +151,13 @@ register char *p;
  *
  * returns: non-0 on match
  */
-int 
-wildmat(s, p)
-char *s;
-char *p;
+int wildmat(const char *s, const char *p)
 {
-    if ((*p == '?' || *p == '*') && *s == '.')
-    {
-	return FALSE;
-    }
-    else
-    {
-	return DoMatch(s, p) == TRUE;
-    }
+  if ((*p == '?' || *p == '*') && *s == '.') {
+    return FALSE;
+  } else {
+    return DoMatch(s, p) == TRUE;
+  }
 }
 
 #ifdef STAND_ALONE_TEST
@@ -185,26 +167,22 @@ char *p;
  * usage: wildmat <pattern> <test arg(s)>
  */
 
-void
-main(argc, argv)
-int argc;
-char *argv[];
+int main(int argc, char **argv)
 {
-    int index;
-    int status = FALSE;
+  int index;
+  int status = FALSE;
 
-    for (index = 2; index < argc; ++index)
-    {
-	if (wildmat(argv[index], argv[1]))
-	{
-	    if (status)
-		fputs(" ", stdout);
-	    printf("%s", argv[index]);
-	    status = TRUE;
-	}
+  for (index = 2; index < argc; ++index) {
+    if (wildmat(argv[index], argv[1])) {
+      if (status)
+        fputs(" ", stdout);
+      printf("%s", argv[index]);
+      status = TRUE;
     }
+  }
 
-    printf("%s\n", status ? "" : argv[1]);
+  printf("%s\n", status ? "" : argv[1]);
+  return 0;
 }
 
 #endif
