@@ -10,6 +10,10 @@
  *		as published by the Free Software Foundation; either version
  *		2 of the License, or (at your option) any later version.
  *
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
  * hgk+jl 02.98 File selection window (no longer used this way..)
  */
 #ifdef HAVE_CONFIG_H
@@ -17,7 +21,7 @@
 #endif
 
 #include "rcsid.h"
-RCSID("$Id: windiv.c,v 1.8 2006/10/11 20:46:21 al-guest Exp $")
+RCSID("$Id: windiv.c,v 1.10 2007-10-10 20:18:20 al-guest Exp $")
 
 #include <dirent.h>
 #include <sys/stat.h>
@@ -46,13 +50,13 @@ static WIN *vmc_tell(const char *fmt, va_list va)
 
   vsnprintf(buf, sizeof(buf), fmt, va);
 
-  w = wopen((COLS / 2) - 2 - mbslen(buf) / 2, 8,
+  w = mc_wopen((COLS / 2) - 2 - mbslen(buf) / 2, 8,
 	    (COLS / 2) + 2 + mbslen(buf) / 2, 10,
 	     BDOUBLE, stdattr, mfcolor, mbcolor, 0, 0, 1);
-  wcursor(w, CNONE);
-  wlocate(w, 2, 1);
-  wputs(w, buf);
-  wredraw(w, 1);
+  mc_wcursor(w, CNONE);
+  mc_wlocate(w, 2, 1);
+  mc_wputs(w, buf);
+  mc_wredraw(w, 1);
   return w;
 }
 
@@ -79,11 +83,11 @@ void werror(const char *s, ...)
   tellwin = vmc_tell(s, ap);
   va_end(ap);
   sleep(2);
-  wclose(tellwin, 1);
+  mc_wclose(tellwin, 1);
 }
 
 /*
- * Vertical "wselect" function.
+ * Vertical "mc_wselect" function.
  */
 int ask(const char *what, const char **s)
 {
@@ -102,42 +106,42 @@ int ask(const char *what, const char **s)
     size = mbslen(what) / 2 + 2;
     offs = size - 5*num;
   }
-  w = wopen((COLS / 2) - size , 8, (COLS / 2) + 1 + size, 9,
+  w = mc_wopen((COLS / 2) - size , 8, (COLS / 2) + 1 + size, 9,
              BSINGLE, stdattr, mfcolor, mbcolor, 0, 0, 1);
 
   dirflush = 0;
 
-  wcursor(w, CNONE);
-  wlocate(w, 1 + size - (mbslen(what) / 2), 0);
-  wputs(w, what);
+  mc_wcursor(w, CNONE);
+  mc_wlocate(w, 1 + size - (mbslen(what) / 2), 0);
+  mc_wputs(w, what);
 
   for (f = 1; f < num; f++) {
-    wlocate(w, 2 + offs + 10*f, 1);
-    wputs(w, _(s[f]));
+    mc_wlocate(w, 2 + offs + 10*f, 1);
+    mc_wputs(w, _(s[f]));
   }
-  wredraw(w, 1);
+  mc_wredraw(w, 1);
 
   while (1) {
-    wlocate(w, 2 + offs + 10 * cur, 1);
+    mc_wlocate(w, 2 + offs + 10 * cur, 1);
     if (!useattr)
-      wprintf(w, ">%s", _(s[cur]) + 1);
+      mc_wprintf(w, ">%s", _(s[cur]) + 1);
     else {
-      wsetattr(w, XA_REVERSE | stdattr);
-      wputs(w, _(s[cur]));
+      mc_wsetattr(w, XA_REVERSE | stdattr);
+      mc_wputs(w, _(s[cur]));
     }
     ocur = cur;
-    wflush();
+    mc_wflush();
     switch (c = wxgetch()) {
       case ' ':
       case 27:
       case 3:
         dirflush = 1;
-        wclose(w, 1);
+        mc_wclose(w, 1);
         return -1;
       case '\r':
       case '\n':
         dirflush = 1;
-        wclose(w, 1);
+        mc_wclose(w, 1);
         return cur;
       case K_LT:
       case 'h':
@@ -149,12 +153,12 @@ int ask(const char *what, const char **s)
         cur = (cur + 1) % num;
         break;
     }
-    wlocate(w, 2 + offs + 10 * ocur, 1);
-    wsetattr(w, stdattr);
+    mc_wlocate(w, 2 + offs + 10 * ocur, 1);
+    mc_wsetattr(w, stdattr);
     if (!useattr)
-      wputs(w, " ");
+      mc_wputs(w, " ");
     else
-      wputs(w, _(s[ocur]));
+      mc_wputs(w, _(s[ocur]));
   }
 }
 
@@ -165,14 +169,14 @@ char *input(char *s, char *buf)
 {
   WIN *w;
 
-  w = wopen((COLS / 2) - 20, 11, (COLS / 2) + 20, 12,
+  w = mc_wopen((COLS / 2) - 20, 11, (COLS / 2) + 20, 12,
              BDOUBLE, stdattr, mfcolor, mbcolor, 1, 0, 1);
-  wputs(w, s);
-  wlocate(w, 0, 1);
-  wprintf(w, "> %-38.38s", buf);
-  wlocate(w, 2, 1);
-  if (wgets(w, buf, 38, 128) < 0)
+  mc_wputs(w, s);
+  mc_wlocate(w, 0, 1);
+  mc_wprintf(w, "> %-38.38s", buf);
+  mc_wlocate(w, 2, 1);
+  if (mc_wgets(w, buf, 38, 128) < 0)
     buf = NULL;
-  wclose(w, 1);
+  mc_wclose(w, 1);
   return buf;
 }
