@@ -11,6 +11,10 @@
  *		as published by the Free Software Foundation; either version
  *		2 of the License, or (at your option) any later version.
  *
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
  * 01.01.98 dickey@clark.net: fix for a history window closing bug
  * fmg 8/20/97: Added support for Search of History Buffer
  */
@@ -19,11 +23,12 @@
 #endif
 
 #include "rcsid.h"
-RCSID("$Id: window.c,v 1.18 2005/11/06 19:20:57 al-guest Exp $")
+RCSID("$Id: window.c,v 1.21 2008-02-06 21:49:55 al-guest Exp $")
 
 #include <limits.h>
 #include <stdarg.h>
 #include <wchar.h>
+#include <termcap.h>
 
 #include "port.h"
 #include "minicom.h"
@@ -153,7 +158,7 @@ int debug(char *s, ...)
 /*
  * Flush the screen buffer
  */
-void wflush(void)
+void mc_wflush(void)
 {
   int todo, done;
 
@@ -179,10 +184,10 @@ static int outchar(int c)
 {
   *_bufpos++ = c;
   if (_bufpos >= _buffend)
-    wflush();
+    mc_wflush();
 #if defined(SMOOTH)
   if (curwin == us && (c == '\n' || c == '\r'))
-    wflush();
+    mc_wflush();
 #endif
   return 0;
 }
@@ -428,7 +433,7 @@ static void _cursor(int type)
 /*
  * Resize a window
  */
-void wresize(WIN *win, int lines, int cols)
+void mc_wresize(WIN *win, int lines, int cols)
 {
   int x, y;
   ELM *oldmap, *newmap, *e, *n;
@@ -472,7 +477,7 @@ void wresize(WIN *win, int lines, int cols)
 /*
  * Create a new window.
  */
-WIN *wopen(int x1, int y1, int x2, int y2, int border, int attr,
+WIN *mc_wopen(int x1, int y1, int x2, int y2, int border, int attr,
            int fg, int bg, int direct, int histlines, int doclr)
 {
   WIN *w;
@@ -597,18 +602,18 @@ WIN *wopen(int x1, int y1, int x2, int y2, int border, int attr,
       _gotoxy(x1 + 1, y1 + 1);
   } else
     if (doclr)
-      winclr(w);
-  wcursor(w, CNORMAL);
+      mc_winclr(w);
+  mc_wcursor(w, CNORMAL);
 
   if (w->direct)
-    wflush();
+    mc_wflush();
   return w;
 }
 
 /*
  * Close a window.
  */
-void wclose(WIN *win, int replace)
+void mc_wclose(WIN *win, int replace)
 {
   ELM *e;
   int x, y;
@@ -632,7 +637,7 @@ void wclose(WIN *win, int replace)
     win->y1--;
     win->y2++;
   }
-  wcursor(win, win->o_cursor);
+  mc_wcursor(win, win->o_cursor);
   if (replace) {
     for (y = win->y1; y <= win->y2; y++) {
       /* temporal way to avoid 'half-character' problem */
@@ -656,7 +661,7 @@ void wclose(WIN *win, int replace)
   if (win->histbuf)
     free(win->histbuf);
   free(win);	/* 1.1.98 dickey@clark.net  */
-  wflush();
+  mc_wflush();
 }
 
 static int oldx, oldy;
@@ -665,7 +670,7 @@ static int ocursor;
 /*
  * Clear screen & restore keyboard modes
  */
-void wleave(void)
+void mc_wleave(void)
 {
   oldx = curx;
   oldy = cury;
@@ -687,10 +692,10 @@ void wleave(void)
     outstr(KE);
   if (RS != NULL)
     outstr(RS);
-  wflush();
+  mc_wflush();
 }
 
-void wreturn(void)
+void mc_wreturn(void)
 {
   int x, y;
   ELM *e;
@@ -722,13 +727,13 @@ void wreturn(void)
     }
   }
   _gotoxy(oldx, oldy);
-  wflush();
+  mc_wflush();
 }
 
 /*
  * Redraw the whole window.
  */
-void wredraw(WIN *w, int newdirect)
+void mc_wredraw(WIN *w, int newdirect)
 {
   int minx, maxx, miny, maxy;
   ELM *e;
@@ -762,7 +767,7 @@ void wredraw(WIN *w, int newdirect)
   }
   _gotoxy(w->x1 + w->curx, w->y1 + w->cury);
   _cursor(w->cursor);
-  wflush();
+  mc_wflush();
   w->direct = newdirect;
 }
 
@@ -795,7 +800,7 @@ static int _wclreol(WIN *w)
 /*
  * Scroll a window.
  */
-void wscroll(WIN *win, int dir)
+void mc_wscroll(WIN *win, int dir)
 {
   ELM *e, *f;
   char *src, *dst;
@@ -970,13 +975,13 @@ void wscroll(WIN *win, int dir)
   if (!_intern && win->direct)
     _gotoxy(win->x1 + win->curx, win->y1 + win->cury);
   if (dirflush && !_intern && win->direct)
-    wflush();
+    mc_wflush();
 }
 
 /*
  * Locate the cursor in a window.
  */
-void wlocate(WIN *win, int x, int y)
+void mc_wlocate(WIN *win, int x, int y)
 {
   if (x < 0)
     x = 0;
@@ -993,13 +998,13 @@ void wlocate(WIN *win, int x, int y)
     _gotoxy(win->x1 + x, win->y1 + y);
 
   if (dirflush)
-    wflush();
+    mc_wflush();
 }
 
 /*
  * Print a character in a window.
  */
-void wputc(WIN *win, wchar_t c)
+void mc_wputc(WIN *win, wchar_t c)
 {
   int mv = 0;
 
@@ -1019,11 +1024,11 @@ void wputc(WIN *win, wchar_t c)
       mv++;
       break;
     case '\007':
-      wbell();
+      mc_wbell();
       break;
     case '\t':
       do {
-        wputc(win, ' '); /* Recursion! */
+        mc_wputc(win, ' '); /* Recursion! */
       } while (win->curx % 8);
       break;
     case '\n':
@@ -1039,7 +1044,7 @@ void wputc(WIN *win, wchar_t c)
         mv++;
         if (win->cury == win->sy2 - win->y1 + 1) {
           if (win->doscroll)
-            wscroll(win, S_UP);
+            mc_wscroll(win, S_UP);
           else
             win->cury = win->sy1 - win->y1;
         }
@@ -1064,11 +1069,11 @@ void wputc(WIN *win, wchar_t c)
     _gotoxy(win->x1 + win->curx, win->y1 + win->cury);
 
   if (win->direct && dirflush && !_intern)
-    wflush();
+    mc_wflush();
 }
 
 /* Draw one line in a window */
-void wdrawelm(WIN *w, int y, ELM *e)
+void mc_wdrawelm(WIN *w, int y, ELM *e)
 {
   int x;
 
@@ -1085,7 +1090,7 @@ void wdrawelm(WIN *w, int y, ELM *e)
  * 'accumulate' one line of ELM's into a string
  * WHY: need this in search function to see if line contains search pattern
  */
-void wdrawelm_var(WIN *w, ELM *e, wchar_t *buf)
+void mc_wdrawelm_var(WIN *w, ELM *e, wchar_t *buf)
 {
   int x, c = 0;
 
@@ -1101,7 +1106,7 @@ void wdrawelm_var(WIN *w, ELM *e, wchar_t *buf)
  * 'draw' one line of ELM's in a window INVERTED (text-mode-wise)
  * WHY: need this in search function to see if line contains search pattern
  */
-void wdrawelm_inverse(WIN *w, int y, ELM *e)
+void mc_wdrawelm_inverse(WIN *w, int y, ELM *e)
 {
   int x;
 
@@ -1127,7 +1132,7 @@ void wdrawelm_inverse(WIN *w, int y, ELM *e)
 /*
  * Print a string in a window.
  */
-void wputs(WIN *win, const char *s)
+void mc_wputs(WIN *win, const char *s)
 {
   _intern = 1;
 
@@ -1135,10 +1140,10 @@ void wputs(WIN *win, const char *s)
     wchar_t wc;
 
     s += one_mbtowc(&wc, s, MB_LEN_MAX);
-    wputc(win, wc);
+    mc_wputc(win, wc);
   }
   if (dirflush && win->direct)
-    wflush();
+    mc_wflush();
   _intern = 0;
 }
 
@@ -1146,7 +1151,7 @@ void wputs(WIN *win, const char *s)
  * Print a formatted string in a window.
  * Should return stringlength - but who cares.
  */
-int wprintf(WIN *win, const char *fmt, ...)
+int mc_wprintf(WIN *win, const char *fmt, ...)
 {
   char buf[160];
   va_list va;
@@ -1154,7 +1159,7 @@ int wprintf(WIN *win, const char *fmt, ...)
   va_start(va, fmt);
   vsnprintf(buf, sizeof(buf), fmt, va);
   va_end(va);
-  wputs(win, buf);
+  mc_wputs(win, buf);
 
   return 0;
 }
@@ -1162,7 +1167,7 @@ int wprintf(WIN *win, const char *fmt, ...)
 /*
  * Sound a bell.
  */
-void wbell(void)
+void mc_wbell(void)
 {
   if (BL != NULL)
     outstr(BL);
@@ -1170,23 +1175,23 @@ void wbell(void)
     outstr(VB);
   else
     outchar('\007');
-  wflush();
+  mc_wflush();
 }
 
 /*
  * Set cursor type.
  */
-void wcursor(WIN *win, int type)
+void mc_wcursor(WIN *win, int type)
 {
   win->cursor = type;
   if (win->direct) {
     _cursor(type);
     if (dirflush)
-      wflush();
+      mc_wflush();
   }
 }
 
-void wtitle(WIN *w, int pos, const char *s)
+void mc_wtitle(WIN *w, int pos, const char *s)
 {
   int x = 0;
 
@@ -1220,7 +1225,7 @@ void wtitle(WIN *w, int pos, const char *s)
   if (w->direct) {
     _gotoxy(w->x1 + w->curx, w->y1 + w->cury);
     if (dirflush)
-      wflush();
+      mc_wflush();
   }
 }
 
@@ -1230,7 +1235,7 @@ void wtitle(WIN *w, int pos, const char *s)
 /*
  * Change attributes of one line of a window.
  */
-void wcurbar(WIN *w, int y, int attr)
+void mc_wcurbar(WIN *w, int y, int attr)
 {
   ELM *e;
   int x;
@@ -1261,13 +1266,13 @@ void wcurbar(WIN *w, int y, int attr)
   if ((VI == NULL || _curstype == CNORMAL) && w->direct)
     _gotoxy(w->x1, y);
   if (w->direct)
-    wflush();
+    mc_wflush();
 }
 
 /*
- * wselect - select one of many choices.
+ * mc_wselect - select one of many choices.
  */
-int wselect(int x, int y, const char *const *choices,
+int mc_wselect(int x, int y, const char *const *choices,
             void (*const *funlist)(void),
             const char *title, int attr, int fg, int bg)
 {
@@ -1295,25 +1300,25 @@ int wselect(int x, int y, const char *const *choices,
     high_off = attr;
   }
 
-  if ((w = wopen(x, y, x + len + 2, y + count - 1,
+  if ((w = mc_wopen(x, y, x + len + 2, y + count - 1,
                  BDOUBLE, attr, fg, bg, 0, 0, 0)) == NULL)
     return -1;
-  wcursor(w, CNONE);
+  mc_wcursor(w, CNONE);
 
   if (title != NULL)
-    wtitle(w, TMID, title);
+    mc_wtitle(w, TMID, title);
 
   for (c = 0; c < count; c++)
-    wprintf(w, " %s%s", _(choices[c]), c == count - 1 ? "" : "\n");
+    mc_wprintf(w, " %s%s", _(choices[c]), c == count - 1 ? "" : "\n");
 
-  wcurbar(w, cur, high_on);
-  wredraw(w, 1);
+  mc_wcurbar(w, cur, high_on);
+  mc_wredraw(w, 1);
 
   while (1) {
     while ((c = wxgetch()) != 27 && c != '\n' && c!= '\r' && c != ' ') {
       if (c == K_UP || c == K_DN || c == 'j' || c == 'k' ||
           c == K_HOME || c == K_END)
-        wcurbar(w, cur, high_off);
+        mc_wcurbar(w, cur, high_off);
       switch (c) {
         case K_UP:
         case 'k':
@@ -1336,19 +1341,19 @@ int wselect(int x, int y, const char *const *choices,
       }
       if (c == K_UP || c == K_DN || c == 'j' || c == 'k' ||
           c == K_HOME || c == K_END)
-        wcurbar(w, cur, high_on);
+        mc_wcurbar(w, cur, high_on);
     }
-    wcursor(w, CNORMAL);
+    mc_wcursor(w, CNORMAL);
     if (c == ' ' || c == 27) {
-      wclose(w, 1);
+      mc_wclose(w, 1);
       return 0;
     }
     if (funlist == NULL || funlist[cur] == NULL) {
-      wclose(w, 1);
+      mc_wclose(w, 1);
       return cur + 1;
     }
     (*funlist[cur])();
-    wcursor(w, CNONE);
+    mc_wcursor(w, CNONE);
   }
 }
 
@@ -1358,7 +1363,7 @@ int wselect(int x, int y, const char *const *choices,
 /*
  * Clear characters.
  */
-void wclrch(WIN *w, int n)
+void mc_wclrch(WIN *w, int n)
 {
   int x, y, x_end;
 
@@ -1380,37 +1385,37 @@ void wclrch(WIN *w, int n)
     _write(' ', w->direct, x, y, w->attr, w->color);
 
   if (w->direct && dirflush)
-    wflush();
+    mc_wflush();
 }
 
 /*
  * Clear entire line.
  */
-void wclrel(WIN *w)
+void mc_wclrel(WIN *w)
 {
   int ocurx = w->curx;
 
   w->curx = 0;
   _wclreol(w);
   w->curx = ocurx;
-  wlocate(w, ocurx, w->cury);
+  mc_wlocate(w, ocurx, w->cury);
 }
 
 /*
  * Clear to end of line.
  */
-void wclreol(WIN *w)
+void mc_wclreol(WIN *w)
 {
   if (_wclreol(w) && w->direct)
     _gotoxy(w->x1 + w->curx, w->y1 + w->cury);
   if (dirflush)
-    wflush();
+    mc_wflush();
 }
 
 /*
  * Clear to begin of line
  */
-void wclrbol(WIN *w)
+void mc_wclrbol(WIN *w)
 {
   int x, y, n;
 
@@ -1431,14 +1436,14 @@ void wclrbol(WIN *w)
   if (w->direct) {
     _gotoxy(n, y);
     if (dirflush)
-      wflush();
+      mc_wflush();
   }
 }
 
 /*
  * Clear to end of screen
  */
-void wclreos(WIN *w)
+void mc_wclreos(WIN *w)
 {
   int y;
   int ocurx, ocury;
@@ -1457,13 +1462,13 @@ void wclreos(WIN *w)
   if (_wclreol(w) && w->direct)
     _gotoxy(w->x1 + w->curx, w->y1 + w->cury);
   if (dirflush && w->direct)
-    wflush();
+    mc_wflush();
 }
 
 /*
  * Clear to begin of screen.
  */
-void wclrbos(WIN *w)
+void mc_wclrbos(WIN *w)
 {
   int ocurx, ocury;
   int y;
@@ -1479,13 +1484,13 @@ void wclrbos(WIN *w)
   }
   w->curx = ocurx;
   w->cury = ocury;
-  wclrbol(w);
+  mc_wclrbol(w);
 }
 
 /*
  * Clear a window.
  */
-void winclr(WIN *w)
+void mc_winclr(WIN *w)
 {
   int y;
   int olddir = w->direct;
@@ -1542,12 +1547,12 @@ void winclr(WIN *w)
   w->direct = olddir;
   _gotoxy(w->x1, w->y1);
   if (dirflush)
-    wflush();
+    mc_wflush();
 }
 
 /* ==== Insert / Delete functions ==== */
 
-void winsline(WIN *w)
+void mc_winsline(WIN *w)
 {
   int osy1, osy2;
 
@@ -1560,13 +1565,13 @@ void winsline(WIN *w)
     w->sy1 = osy1;
   if (w->sy2 > osy2)
     w->sy2 = osy2;
-  wscroll(w, S_DOWN);
+  mc_wscroll(w, S_DOWN);
 
   w->sy1 = osy1;
   w->sy2 = osy2;
 }
 
-void wdelline(WIN *w)
+void mc_wdelline(WIN *w)
 {
   int osy1, osy2;
   int ocury;
@@ -1583,9 +1588,9 @@ void wdelline(WIN *w)
     w->sy2 = osy2;
 
   _intern = 1;
-  wscroll(w, S_UP);
+  mc_wscroll(w, S_UP);
   _intern = 0;
-  wlocate(w, 0, ocury);
+  mc_wlocate(w, 0, ocury);
 
   w->sy1 = osy1;
   w->sy2 = osy2;
@@ -1594,7 +1599,7 @@ void wdelline(WIN *w)
 /*
  * Insert a space at cursor position.
  */
-void winschar2(WIN *w, wchar_t c, int move)
+void mc_winschar2(WIN *w, wchar_t c, int move)
 {
   int y;
   int x;
@@ -1609,7 +1614,7 @@ void winschar2(WIN *w, wchar_t c, int move)
 
   /* See if we need to insert. */
   if (c == 0 || wcschr(L"\r\n\t\b\007", c) || w->curx >= w->xs - 1) {
-    wputc(w, c);
+    mc_wputc(w, c);
     return;
   }
 
@@ -1639,7 +1644,7 @@ void winschar2(WIN *w, wchar_t c, int move)
   memcpy(buf, gmap + COLS * y + x, sizeof(ELM) * len);
 
   /* Now, put the new character on screen. */
-  wputc(w, c);
+  mc_wputc(w, c);
   if (!move)
     w->curx = oldx;
 
@@ -1652,18 +1657,18 @@ void winschar2(WIN *w, wchar_t c, int move)
   free(buf);
 
   w->direct = odir;
-  wlocate(w, w->curx, w->cury);
+  mc_wlocate(w, w->curx, w->cury);
 }
 
-void winschar(WIN *w)
+void mc_winschar(WIN *w)
 {
-  winschar2(w, ' ', 0);
+  mc_winschar2(w, ' ', 0);
 }
 
 /*
  * Delete character under the cursor.
  */
-void wdelchar(WIN *w)
+void mc_wdelchar(WIN *w)
 {
   int x, y;
   int doit = 1;
@@ -1690,7 +1695,7 @@ void wdelchar(WIN *w)
     e++;
   }
   _write(' ', doit && w->direct, x, y, w->attr, w->color);
-  wlocate(w, w->curx, w->cury);
+  mc_wlocate(w, w->curx, w->cury);
 }
 
 /* ============= Support: edit a line on the screen. ============ */
@@ -1701,11 +1706,11 @@ static void lredraw(WIN *w, int x, int y, wchar_t *s, int len)
   int i, f;
 
   i = 0;
-  wlocate(w, x, y);
+  mc_wlocate(w, x, y);
   for (f = 0; f < len; f++) {
     if (s[f] == 0)
       i++;
-    wputc(w, i ? ' ' : s[f]);
+    mc_wputc(w, i ? ' ' : s[f]);
   }
 }
 
@@ -1715,8 +1720,8 @@ static void lredraw(WIN *w, int x, int y, wchar_t *s, int len)
 #  define BUFLEN 256
 #endif
 
-/* wgetwcs - edit one line in a window. */
-int wgetwcs(WIN *w, wchar_t *s, int linelen, int maxlen)
+/* mc_wgetwcs - edit one line in a window. */
+int mc_wgetwcs(WIN *w, wchar_t *s, int linelen, int maxlen)
 {
   int c;
   int idx;
@@ -1740,9 +1745,9 @@ int wgetwcs(WIN *w, wchar_t *s, int linelen, int maxlen)
   if ((idx = wcslen(s)) > linelen)
     idx = linelen;
   wcsncpy(buf, s, sizeof(buf) / sizeof(*buf));
-  wlocate(w, x + idx, y);
+  mc_wlocate(w, x + idx, y);
   dirflush = 0;
-  wflush();
+  mc_wflush();
 
   while (!quit) {
     if (once) {
@@ -1760,9 +1765,9 @@ int wgetwcs(WIN *w, wchar_t *s, int linelen, int maxlen)
         quit = 1;
         break;
       case K_ESC: /* Exit without changing. */
-        wlocate(w, x, y);
+        mc_wlocate(w, x, y);
         lredraw(w, x, y, s, linelen);
-        wflush();
+        mc_wflush();
         st = -1;
         quit = 1;
         break;
@@ -1772,8 +1777,8 @@ int wgetwcs(WIN *w, wchar_t *s, int linelen, int maxlen)
         idx = 0;
         if (r)
           lredraw(w, x, y, buf, linelen);
-        wlocate(w, x, y);
-        wflush();
+        mc_wlocate(w, x, y);
+        mc_wflush();
         break;
       case K_END: /* End of line. */
         idx = wcslen(buf);
@@ -1784,8 +1789,8 @@ int wgetwcs(WIN *w, wchar_t *s, int linelen, int maxlen)
         }
         if (r)
           lredraw(w, x, y, buf + offs, linelen);
-        wlocate(w, x + idx - offs, y);
-        wflush();
+        mc_wlocate(w, x + idx - offs, y);
+        mc_wflush();
         break;
       case K_LT: /* Cursor left. */
       case K_BS: /* Backspace is first left, then DEL. */
@@ -1798,8 +1803,8 @@ int wgetwcs(WIN *w, wchar_t *s, int linelen, int maxlen)
           lredraw(w, x, y, buf + offs, linelen);
         }
         if (c == K_LT) {
-          wlocate(w, x + idx - offs, y);
-          wflush();
+          mc_wlocate(w, x + idx - offs, y);
+          mc_wflush();
           break;
         }
         /*FALLTHRU*/
@@ -1809,8 +1814,8 @@ int wgetwcs(WIN *w, wchar_t *s, int linelen, int maxlen)
         for (f = idx; buf[f]; f++)
           buf[f] = buf[f+1];
         lredraw(w, x + idx - offs, y, buf + idx, linelen - (idx - offs));
-        wlocate(w, x + idx - offs, y);
-        wflush();
+        mc_wlocate(w, x + idx - offs, y);
+        mc_wflush();
         break;
       case K_RT:
         if (buf[idx] == 0)
@@ -1820,8 +1825,8 @@ int wgetwcs(WIN *w, wchar_t *s, int linelen, int maxlen)
           offs += 4;
           lredraw(w, x, y, buf + offs, linelen);
         }
-        wlocate(w, x + idx - offs, y);
-        wflush();
+        mc_wlocate(w, x + idx - offs, y);
+        mc_wflush();
         break;
       default:
         /* If delete == 1, delete the buffer. */
@@ -1831,9 +1836,9 @@ int wgetwcs(WIN *w, wchar_t *s, int linelen, int maxlen)
           buf[0] = 0;
           idx = 0;
           offs = 0;
-          wlocate(w, x, y);
+          mc_wlocate(w, x, y);
           for (f = 0; f < i; f++)
-            wputc(w, ' ');
+            mc_wputc(w, ' ');
           delete = 0;
         }
 
@@ -1854,8 +1859,8 @@ int wgetwcs(WIN *w, wchar_t *s, int linelen, int maxlen)
         } else
           lredraw(w, x + idx - offs, y, buf + idx, linelen - (idx - offs));
         idx++;
-        wlocate(w, x + idx - offs, y);
-        wflush();
+        mc_wlocate(w, x + idx - offs, y);
+        mc_wflush();
         break;
     }
   }
@@ -1865,8 +1870,8 @@ int wgetwcs(WIN *w, wchar_t *s, int linelen, int maxlen)
   return st;
 }
 
-/* wgets - edit one line in a window. */
-int wgets(WIN *w, char *s, int linelen, int maxlen)
+/* mc_wgets - edit one line in a window. */
+int mc_wgets(WIN *w, char *s, int linelen, int maxlen)
 {
   int st;
   wchar_t buf[BUFLEN];
@@ -1877,7 +1882,7 @@ int wgets(WIN *w, char *s, int linelen, int maxlen)
   for (i = 0; *sptr != 0 && i < sizeof (buf) - 1; i++)
     sptr += one_mbtowc(buf + i, sptr, MB_LEN_MAX);
   buf[i] = 0;
-  st = wgetwcs(w, buf, linelen, maxlen);
+  st = mc_wgetwcs(w, buf, linelen, maxlen);
   if (st == 0) {
     sptr = s;
     for (i = 0; buf[i] != 0; i++)
@@ -2135,7 +2140,7 @@ int win_init(int fg, int bg, int attr)
 
   setcbreak(1);          /* Cbreak, no echo */
 
-  winclr(stdwin);
+  mc_winclr(stdwin);
   w_init = 1;
   return 0;
 }
@@ -2148,12 +2153,12 @@ void win_end(void)
   stdwin->attr = XA_NORMAL;
   stdwin->color = COLATTR(WHITE, BLACK);
   _setattr(stdwin->attr, stdwin->color);
-  winclr(stdwin);
+  mc_winclr(stdwin);
 #ifdef ST_LINE
   if (DS)
     outstr(DS);
 #endif
-  wcursor(stdwin, CNORMAL);
+  mc_wcursor(stdwin, CNORMAL);
   if (KE != NULL)
     outstr(KE);
   if (RS != NULL)
@@ -2161,7 +2166,7 @@ void win_end(void)
   else if (IS != NULL)
     outstr(IS);
 
-  wflush();
+  mc_wflush();
   free(gmap);
   gmap = NULL;
   stdwin = NULL;
